#!/usr/bin/env python
# -*- coding: utf-8 -*-

# License: 3 Clause BSD
# Part of Carpyncho - http://carpyncho.jbcabral.org


# =============================================================================
# DOCS
# =============================================================================

"""Constants for tff wrapper

"""

# =============================================================================
# IMPORTS
# =============================================================================

import sys
import os

from six.moves import configparser


# =============================================================================
# CONSTANTS
# =============================================================================

IS_WINDOWS = sys.platform.startswith("win")

PRJ = "pytff"

HOME_PATH = os.path.expanduser("~")

APPDATA_PATH = os.getenv("APPDATA", HOME_PATH) if IS_WINDOWS else HOME_PATH

CONF_DIR_PATH = (
    os.path.join(APPDATA_PATH, PRJ)
    if IS_WINDOWS else os.path.join(APPDATA_PATH, ".config", PRJ))

CONF_FILE_PATH = os.path.join(CONF_DIR_PATH, "pytff.rc")

DEFAULTS = {
    "tff_cmd": "tff",
    "wrk_path": None,
    "fmt": "%.5f"
}


# ============================================================================
# READ CONFIGURATION
# =============================================================================

if not os.path.isfile(CONF_FILE_PATH):
    if not os.path.exists(CONF_DIR_PATH):
        os.makedirs(CONF_DIR_PATH)
    with open(CONF_FILE_PATH, "wb") as fp:

        config = configparser.RawConfigParser()
        config.add_section(PRJ)
        for k, v in DEFAULTS.items():
            v = "" if v is None else v
            config.set(PRJ, k, v)
        config.write(fp)

config = configparser.RawConfigParser()
config.read(CONF_FILE_PATH)
config = dict(list(DEFAULTS.items()) + list(config.items(PRJ)))


# =============================================================================
# CONSTANTS
# =============================================================================

FMT = config["fmt"]

TFF_CMD = config["tff_cmd"]

WRK_PATH = config["wrk_path"]

LIS_FNAME = "target.lis"

TEMPLATE_FNAME = "template.dat"

PAR_FNAME = "tff.par"

TFF_DAT_FNAME = "tff.dat"

DFF_DAT_FNAME = "dff.dat"

MATCH_DAT_FNAME = "match.dat"

TFF_PAR_TEMPLATE = """
*
***************************************************************
*  This is the input parameter file for code  'tff'           *
*  Please check the source for the meaning of the parameters. *
*  For changing parameters please use space only between      *
*  columns 11-20. No exponential format please. Do not delete *
*  or add any lines. Comments can be added from column 22-80. *
***************************************************************
*
ntbin    = {ntbin}
nmin     = {nmin}
mindp    = {mindp}
snr1min  = {snr1min}
nmatch   = {nmatch}
dph      = {dph}
asig     = {asig}
jfit     = {jfit}
""".rstrip()

TARGET_LIS_LINE_TEMPLATE = """
{src_id}
{period}
{target_path}
""".strip()


TEMPLATE_DAT_SRC = """
IU Car
  0.7371495000    0.0000  11.990     162  0.0170
  0.3639  4.2181  0.1674  4.6741  0.1010  5.1667  0.0684  5.9815  0.0432  0.5701
  0.0220  1.2653  0.0097  1.8669  0.0046  2.9456  0.0026  3.4787  0.0023  5.2378
  0.0015  4.5339  0.0023  5.3795  0.0025  1.5850  0.0010  2.0312  0.0011  2.5335
TZ Aur
  0.3916739000    0.0000  11.947     117  0.0234
  0.4508  4.6153  0.2519  5.4445  0.1478  0.3263  0.1005  1.4624  0.0673  2.5694
  0.0473  3.6291  0.0332  4.6664  0.0241  5.7161  0.0168  0.4629  0.0134  1.3722
  0.0098  2.3182  0.0090  3.3463  0.0067  4.6048  0.0048  5.5869  0.0016  6.2297
V341 Aql
  0.5780205400    0.0000  10.939     530  0.0204
  0.4230  2.2937  0.2276  0.7027  0.1351  5.6723  0.0989  4.5168  0.0501  3.3801
  0.0355  1.7553  0.0272  0.4555  0.0178  5.6574  0.0082  4.0529  0.0072  2.5405
  0.0029  1.1927  0.0019  5.6800  0.0009  2.2918  0.0024  0.7950  0.0025  0.6623
SW And
  0.4422659020    0.0000   9.730     462  0.0091
  0.3218  0.0179  0.1803  2.6140  0.1057  5.4850  0.0590  2.0787  0.0336  4.7398
  0.0203  1.2538  0.0115  4.2029  0.0059  0.8333  0.0025  4.5324  0.0026  1.9495
  0.0033  5.5635  0.0044  1.9820  0.0058  4.6203  0.0051  0.7701  0.0044  3.6286
XX And
  0.7227526000    0.0000  10.739      75  0.0155
  0.3358  1.6476  0.1720  5.9663  0.1134  4.0763  0.0617  2.5336  0.0327  0.7637
  0.0169  5.0608  0.0091  2.8171  0.0064  0.6308  0.0047  4.9410  0.0030  3.1810
  0.0012  1.7614  0.0006  1.7596  0.0013  0.5223  0.0011  5.6820  0.0012  4.6372
WY Ant
  0.5743365000    0.0000  10.892     340  0.0184
  0.3241  2.9349  0.1425  1.9110  0.1110  1.1494  0.0745  0.5286  0.0427  0.0012
  0.0240  5.7267  0.0096  5.0062  0.0071  4.5184  0.0032  4.3242  0.0039  4.4465
  0.0043  4.1754  0.0048  3.5231  0.0061  3.0121  0.0056  2.3907  0.0050  1.7239
SW Aqr
  0.4593029000    0.0000  11.294     147  0.0180
  0.4646  1.8951  0.2167  6.0193  0.1610  4.1492  0.0980  2.3481  0.0737  0.5435
  0.0523  5.1398  0.0351  3.3187  0.0198  1.3537  0.0194  5.7091  0.0167  4.0255
  0.0118  2.3529  0.0080  0.6458  0.0050  5.6980  0.0048  2.3401  0.0009  0.6272
SX Aqr
  0.5357132700    0.0000  11.861     329  0.0394
  0.4046  0.3381  0.1709  2.9299  0.1424  5.7229  0.0942  2.4395  0.0641  5.4375
  0.0446  2.1401  0.0315  5.1106  0.0223  1.7783  0.0158  4.7087  0.0112  1.3322
  0.0079  4.2322  0.0057  0.8642  0.0040  3.8251  0.0028  0.6184  0.0020  3.8915
BO Aqr
  0.6940186000    0.0000  12.228     142  0.0246
  0.3629  2.1503  0.1892  0.5791  0.1208  5.4832  0.0708  4.2925  0.0409  2.9604
  0.0235  1.5356  0.0135  0.0716  0.0075  4.9357  0.0035  3.9847  0.0030  3.4215
  0.0037  2.5902  0.0042  1.4446  0.0040  0.2106  0.0032  5.2665  0.0019  4.0501
BR Aqr
  0.4818785000    0.0000  11.499     166  0.0251
  0.3767  3.4168  0.2000  2.9576  0.1368  2.8274  0.0902  2.7881  0.0588  2.7009
  0.0372  2.5766  0.0228  2.4117  0.0133  2.1867  0.0075  1.8836  0.0042  1.5347
  0.0023  1.1834  0.0007  0.8682  0.0007  3.6934  0.0021  3.6419  0.0032  3.6772
CP Aqr
  0.4634070000    0.0000  11.862     118  0.0176
  0.4309  4.3768  0.2419  4.8695  0.1396  5.6786  0.0973  0.3645  0.0588  1.1697
  0.0398  1.8609  0.0305  2.5665  0.0237  3.3317  0.0171  4.1567  0.0111  5.0192
  0.0063  5.8313  0.0026  0.0970  0.0013  5.7409  0.0023  5.9404  0.0029  0.4238
DN Aqr
  0.6337525000    0.0000  11.259     259  0.0196
  0.2696  1.7357  0.1306  6.0260  0.0830  4.1885  0.0508  2.6352  0.0259  1.0924
  0.0137  5.9332  0.0090  4.5931  0.0077  3.1766  0.0072  1.6377  0.0068  0.0140
  0.0060  4.6479  0.0054  3.0446  0.0045  1.2847  0.0034  5.9128  0.0023  4.2552
AA Aql
  0.3617869000    0.0000  11.905     126  0.0221
  0.4326  6.2224  0.2362  2.1826  0.1520  4.8245  0.1041  1.0346  0.0651  3.6109
  0.0463  6.1234  0.0362  2.3476  0.0284  4.8999  0.0218  1.1862  0.0161  3.7262
  0.0112  6.2617  0.0078  2.4641  0.0051  4.8649  0.0032  0.9447  0.0022  3.0772
X Ari
  0.6511597300    0.0000   9.597     711  0.0151
  0.3391  6.1530  0.1627  2.0577  0.1228  4.5886  0.0792  0.8771  0.0480  3.5468
  0.0229  6.0712  0.0152  2.0778  0.0120  4.6602  0.0083  1.2888  0.0052  4.2567
  0.0028  1.1771  0.0025  4.4463  0.0022  0.6330  0.0018  2.5619  0.0029  5.5274
V Cae
  0.5709160000    0.0000  12.933      87  0.0109
  0.3694  3.8533  0.1747  3.7338  0.1323  3.9218  0.0872  4.1363  0.0587  4.4297
  0.0354  4.6317  0.0194  4.9048  0.0160  5.0178  0.0105  5.2535  0.0064  5.5144
  0.0024  0.0322  0.0026  0.5775  0.0017  1.4936  0.0028  2.3144  0.0024  2.8433
W CVn
  0.5517601200    0.0000  10.577     399  0.0236
  0.3001  2.4078  0.1504  1.1264  0.0903  6.2183  0.0588  5.2673  0.0356  4.2152
  0.0192  3.1723  0.0085  2.3091  0.0043  2.2298  0.0056  1.7469  0.0066  0.8430
  0.0066  6.0475  0.0059  4.9129  0.0047  3.7558  0.0037  2.5594  0.0027  1.3366
V499 Cen
  0.5212100000    0.0000  11.170     202  0.0145
  0.4243  1.8943  0.1917  6.0656  0.1455  4.1908  0.0997  2.4059  0.0679  0.6998
  0.0498  5.2603  0.0312  3.4902  0.0188  1.3753  0.0124  5.9830  0.0150  4.1069
  0.0069  2.7368  0.0053  1.3423  0.0071  5.6637  0.0014  5.2859  0.0034  2.5805
RR Cet
  0.5530287700    0.0000   9.747     742  0.0116
  0.3193  1.6025  0.1558  5.5675  0.1112  3.6169  0.0708  1.6885  0.0408  6.1338
  0.0201  4.1837  0.0109  2.1168  0.0062  0.5691  0.0045  5.6257  0.0038  4.4387
  0.0030  2.7196  0.0053  0.9121  0.0056  5.1591  0.0054  3.2516  0.0052  1.3100
RX Cet
  0.5736870000    0.0000  11.469      71  0.0140
  0.2890  5.7467  0.1428  1.2742  0.1011  3.4548  0.0648  5.7120  0.0347  1.8077
  0.0158  3.8873  0.0080  5.8833  0.0051  2.0270  0.0030  5.5064  0.0041  2.2538
  0.0034  4.9283  0.0024  0.8995  0.0012  2.9899  0.0015  4.7633  0.0012  1.1894
RZ Cet
  0.5106085000    0.0000  11.860     162  0.0281
  0.3526  4.3388  0.1679  4.8548  0.1045  5.3734  0.0520  6.2061  0.0303  0.4993
  0.0192  1.0343  0.0130  1.5921  0.0092  2.2013  0.0065  2.8849  0.0049  3.6922
  0.0035  4.5381  0.0024  5.4166  0.0016  6.2709  0.0007  0.7872  0.0005  1.1020
S Com
  0.5866133000    0.0000  11.707     106  0.0184
  0.4371  3.0290  0.2159  2.0491  0.1409  1.4724  0.0956  0.8453  0.0643  0.2644
  0.0427  5.9563  0.0281  5.3263  0.0187  4.6452  0.0130  3.9316  0.0095  3.2416
  0.0070  2.6296  0.0049  2.1414  0.0031  1.8481  0.0021  1.9099  0.0021  2.1056
V413 CrA
  0.5895000000    0.0000  10.624     165  0.0129
  0.2536  2.3487  0.1149  0.9771  0.0708  6.1224  0.0356  5.1624  0.0147  4.1869
  0.0049  3.6004  0.0043  3.6783  0.0055  2.8756  0.0058  1.8023  0.0055  0.6551
  0.0051  5.7528  0.0045  4.4925  0.0039  3.2801  0.0034  2.0681  0.0030  0.8739
W Crt
  0.4120138500    0.0000  11.626     379  0.0316
  0.4360  5.2593  0.2438  0.3180  0.1448  2.0579  0.1044  3.6485  0.0641  5.4914
  0.0412  0.6722  0.0325  2.3428  0.0216  4.0609  0.0139  5.5799  0.0112  0.8422
  0.0082  2.5232  0.0064  4.0105  0.0052  5.3275  0.0018  0.7163  0.0013  4.1681
DX Del
  0.4726181800    0.0000   9.954     802  0.0098
  0.2563  2.1537  0.1268  0.6213  0.0730  5.7045  0.0323  4.4505  0.0161  3.1502
  0.0065  2.3394  0.0061  1.8884  0.0055  1.2153  0.0079  6.2310  0.0072  4.7936
  0.0046  3.4187  0.0053  2.1910  0.0033  1.0847  0.0038  5.9815  0.0023  4.5609
SU Dra
  0.6604200200    0.0000   9.829      85  0.0092
  0.3364  4.2124  0.1795  4.5242  0.1104  5.2685  0.0673  5.9899  0.0380  0.3820
  0.0228  0.7372  0.0158  1.6038  0.0080  2.7468  0.0046  3.4356  0.0063  5.0070
  0.0022  0.3463  0.0044  0.5803  0.0051  1.0914  0.0035  1.8178  0.0053  2.5397
SW Dra
  0.5696710000    0.0000  10.526     159  0.0051
  0.3163  0.1660  0.1650  2.8345  0.1062  5.7911  0.0670  2.5993  0.0326  5.5939
  0.0182  2.0451  0.0087  5.2725  0.0059  2.5288  0.0036  6.0669  0.0035  3.3938
  0.0051  0.1399  0.0046  3.2072  0.0050  6.2321  0.0042  2.8419  0.0041  5.8158
BK Dra
  0.5920785000    0.0000  11.254     334  0.0159
  0.4205  4.1433  0.1943  4.2705  0.1551  4.7695  0.0935  5.2943  0.0722  5.8614
  0.0403  0.2523  0.0276  0.4414  0.0224  0.9825  0.0188  1.3817  0.0145  1.9202
  0.0094  2.3184  0.0033  2.4769  0.0036  4.7462  0.0017  3.9515  0.0010  5.4905
BT Dra
  0.5883063800    0.0000  11.649     269  0.0160
  0.2850  1.6987  0.1365  5.9038  0.0844  4.0530  0.0495  2.3912  0.0254  0.6324
  0.0103  5.1601  0.0029  3.8778  0.0028  3.6909  0.0042  2.0745  0.0043  0.2287
  0.0035  4.6258  0.0026  2.7847  0.0019  0.8466  0.0013  5.4025  0.0012  3.8025
RX Eri
  0.5872475100    0.0000   9.704     239  0.0092
  0.3101  3.0822  0.1618  2.3907  0.1016  1.9453  0.0618  1.6354  0.0330  1.2279
  0.0172  0.7963  0.0094  0.6025  0.0042  0.6775  0.0046  0.8495  0.0060  0.8416
  0.0064  0.6589  0.0060  0.6077  0.0061  0.1088  0.0045  5.7978  0.0043  5.4715
SV Eri
  0.7137980000    0.0000   9.979     337  0.0103
  0.2890  4.5660  0.0819  5.4245  0.0376  0.1322  0.0090  1.5412  0.0034  1.9983
  0.0010  4.5724  0.0017  0.4681  0.0009  3.9087  0.0021  3.0631  0.0012  6.0695
  0.0013  0.6198  0.0011  0.6642  0.0029  2.9634  0.0013  1.1391  0.0017  0.3271
RR Gem
  0.3973081580    0.0000  11.416      91  0.0135
  0.3996  0.8650  0.2264  4.1763  0.1363  1.4895  0.0906  5.1487  0.0545  2.3904
  0.0350  5.8430  0.0247  3.0086  0.0184  0.2125  0.0137  3.7354  0.0100  0.9864
  0.0070  4.4996  0.0048  1.6681  0.0033  5.0172  0.0026  1.9987  0.0023  5.3008
UW Gru
  0.5482104000    0.0000  13.267     138  0.0176
  0.3597  3.8802  0.1644  3.7090  0.1188  3.9210  0.0795  4.2872  0.0539  4.5028
  0.0333  4.9793  0.0169  4.9721  0.0126  5.2131  0.0078  5.6690  0.0063  0.1926
  0.0025  1.4016  0.0048  1.7047  0.0031  2.2913  0.0043  2.9849  0.0057  2.9357
TW Her
  0.3995999100    0.0000  11.320     142  0.0210
  0.4278  3.6259  0.2401  3.3574  0.1557  3.4849  0.1006  3.4596  0.0666  3.5785
  0.0480  3.5841  0.0346  3.5580  0.0252  3.6010  0.0176  3.5184  0.0126  3.4037
  0.0093  3.3514  0.0070  3.1220  0.0052  2.8964  0.0043  2.8848  0.0046  2.5091
VX Her
  0.4553728000    0.0000  10.783     149  0.0148
  0.4572  5.0402  0.2102  6.0409  0.1624  1.0168  0.1044  2.3820  0.0709  3.7406
  0.0546  5.1825  0.0313  0.3675  0.0219  1.7277  0.0135  2.7505  0.0121  3.8117
  0.0081  5.1948  0.0063  6.0596  0.0054  1.1453  0.0031  2.4556  0.0032  3.7161
VZ Her
  0.4403277300    0.0000  11.567     327  0.0317
  0.4604  4.5273  0.2399  4.9695  0.1450  5.8282  0.0975  0.4228  0.0684  1.2975
  0.0489  2.1656  0.0354  3.0204  0.0256  3.8579  0.0183  4.6798  0.0131  5.4955
  0.0094  0.0189  0.0066  0.8036  0.0045  1.5747  0.0028  2.3264  0.0017  2.9967
SV Hya
  0.4786390000    0.0000  10.599     191  0.0191
  0.4518  1.7448  0.2213  5.6977  0.1335  3.5946  0.0815  1.7262  0.0435  5.8667
  0.0215  3.5739  0.0136  1.0417  0.0127  4.9843  0.0113  2.8882  0.0089  0.9305
  0.0063  5.2077  0.0043  3.0149  0.0033  0.7789  0.0035  4.9700  0.0033  3.0682
DH Hya
  0.4889980000    0.0000  12.226     143  0.0241
  0.4283  1.6924  0.1897  5.5669  0.1525  3.4245  0.1102  1.3856  0.0783  5.6782
  0.0486  3.5353  0.0279  1.3784  0.0218  5.6655  0.0186  3.7136  0.0085  1.7262
  0.0069  5.4500  0.0068  3.6744  0.0052  2.0404  0.0024  5.5621  0.0032  4.2018
FY Hya
  0.6366510000    0.0000  12.628     259  0.0393
  0.3906  5.3871  0.1639  0.5476  0.1324  2.1550  0.0843  3.7098  0.0684  5.5559
  0.0385  1.3448  0.0173  2.7669  0.0202  4.2596  0.0185  0.1878  0.0110  2.5929
  0.0034  4.9604  0.0021  5.1473  0.0042  1.0244  0.0028  3.3669  0.0006  3.2887
RR Leo
  0.4523926000    0.0000  10.806     126  0.0136
  0.4600  2.8752  0.2207  1.7047  0.1617  0.8701  0.0997  0.0992  0.0698  5.5382
  0.0518  4.8209  0.0298  4.0668  0.0178  2.9388  0.0171  2.1004  0.0136  1.4922
  0.0119  0.5652  0.0041  6.2725  0.0026  4.7568  0.0026  4.2555  0.0005  5.4127
SS Leo
  0.6263438000    0.0000  11.097     562  0.0202
  0.3860  5.0074  0.1999  6.1258  0.1284  1.3020  0.0915  2.7623  0.0532  4.3427
  0.0262  5.6082  0.0160  0.4550  0.0133  2.2719  0.0049  4.1816  0.0007  3.9573
  0.0008  3.8446  0.0022  5.3350  0.0050  0.5395  0.0055  1.0651  0.0028  3.2725
ST Leo
  0.4779843000    0.0000  11.578     389  0.0246
  0.4339  0.8526  0.2150  4.0037  0.1553  1.2178  0.1037  4.7200  0.0700  1.9768
  0.0473  5.5123  0.0316  2.7462  0.0211  6.2079  0.0142  3.3152  0.0101  0.3538
  0.0077  3.6789  0.0063  0.7923  0.0051  4.2743  0.0038  1.6257  0.0027  5.3739
TV Leo
  0.6728430000    0.0000  12.166     184  0.0295
  0.4096  3.0629  0.2034  2.2176  0.1388  1.6926  0.0906  1.2423  0.0570  0.7597
  0.0341  0.2370  0.0194  5.9023  0.0104  5.1737  0.0057  4.3083  0.0028  3.3162
  0.0008  1.7556  0.0022  5.8720  0.0043  5.0873  0.0057  4.5393  0.0063  4.0293
V LMi
  0.5439300000    0.0000  11.849      56  0.0186
  0.3867  2.3376  0.1850  0.7752  0.1286  5.7970  0.0840  4.4825  0.0554  3.2283
  0.0389  1.9680  0.0248  0.6892  0.0136  5.5077  0.0101  3.9750  0.0101  2.6768
  0.0065  2.0263  0.0029  1.7579  0.0012  1.9911  0.0016  6.1650  0.0026  5.1371
U Lep
  0.5814775000    0.0000  10.648     237  0.0254
  0.4227  4.0409  0.2023  4.0247  0.1446  4.3664  0.1001  4.7824  0.0685  5.1977
  0.0457  5.5953  0.0295  5.9766  0.0184  0.0363  0.0110  0.3373  0.0065  0.5768
  0.0039  0.7703  0.0022  1.0293  0.0012  1.6864  0.0009  3.0631  0.0015  4.0226
TV Lib
  0.2696239800    0.0000  12.113     178  0.0270
  0.4145  0.4130  0.2236  3.0118  0.1497  5.9507  0.1025  2.6281  0.0723  5.6098
  0.0525  2.3977  0.0389  5.4115  0.0247  1.9321  0.0171  4.6267  0.0137  1.3195
  0.0127  4.4831  0.0094  0.9179  0.0070  3.8109  0.0063  0.3117  0.0041  2.4714
VY Lib
  0.5339377000    0.0000  11.755     182  0.0279
  0.3323  1.5810  0.1719  5.5155  0.1135  3.5836  0.0735  1.6421  0.0460  5.9783
  0.0270  4.0268  0.0140  2.0737  0.0055  0.0882  0.0002  4.7484  0.0026  5.4799
  0.0036  3.4470  0.0037  1.3600  0.0033  5.4915  0.0028  3.2779  0.0026  1.0637
TT Lyn
  0.5974332000    0.0000   9.881     636  0.0092
  0.2559  3.6619  0.1180  3.4779  0.0800  3.6666  0.0441  4.0103  0.0172  4.5126
  0.0063  4.8614  0.0040  5.7970  0.0074  6.2555  0.0080  0.2626  0.0066  0.5058
  0.0052  0.5783  0.0054  0.6282  0.0041  1.3550  0.0048  1.6286  0.0034  1.3602
IO Lyr
  0.5771220000    0.0000  11.855      87  0.0202
  0.3382  3.0680  0.1840  2.2085  0.1074  1.8359  0.0648  1.4625  0.0387  1.0708
  0.0225  0.6624  0.0126  0.2161  0.0069  6.0209  0.0037  5.5917  0.0022  5.4150
  0.0021  5.4918  0.0025  5.3145  0.0026  5.0043  0.0022  4.6950  0.0016  4.4093
KX Lyr
  0.4409050000    0.0000  11.030     152  0.0163
  0.4014  2.2983  0.1866  0.8710  0.1016  5.8585  0.0558  4.5826  0.0253  3.2175
  0.0126  1.7791  0.0070  0.2981  0.0031  4.9369  0.0011  3.8065  0.0001  5.2903
  0.0007  4.1349  0.0006  2.9226  0.0014  1.8028  0.0006  2.3364  0.0011  0.2781
RV Oct
  0.5711665850    0.0000  11.012     398  0.0094
  0.3779  4.1261  0.2041  4.4144  0.1298  5.0012  0.0904  5.6821  0.0490  0.1159
  0.0296  0.4491  0.0233  1.0283  0.0125  1.7947  0.0056  2.4444  0.0037  3.0235
  0.0007  3.8583  0.0020  6.0936  0.0031  0.7461  0.0027  1.2024  0.0037  2.1778
ST Oph
  0.4503564000    0.0000  12.244     154  0.0257
  0.4570  4.8467  0.2232  5.6333  0.1613  0.4916  0.1003  1.6110  0.0723  2.7571
  0.0497  3.9989  0.0285  5.0847  0.0199  6.0403  0.0164  0.8571  0.0082  2.1193
  0.0089  3.1273  0.0069  4.6543  0.0047  5.8273  0.0021  0.8756  0.0031  2.4625
V445 Oph
  0.3970231990    0.0000  11.045     690  0.0167
  0.3085  3.4196  0.1584  3.2291  0.0910  3.1342  0.0450  3.0939  0.0289  2.8226
  0.0171  2.6689  0.0086  2.5040  0.0034  2.2114  0.0009  1.2036  0.0015  5.8327
  0.0023  5.4655  0.0026  5.3221  0.0025  5.2049  0.0020  5.0878  0.0015  4.8649
V452 Oph
  0.5571630000    0.0000  12.303     139  0.0261
  0.3335  1.2315  0.1464  4.7049  0.1142  2.3219  0.0845  6.1097  0.0489  3.8080
  0.0269  1.5287  0.0140  5.5657  0.0070  3.4290  0.0036  1.5638  0.0031  6.1324
  0.0035  4.0418  0.0040  1.7225  0.0043  5.5673  0.0046  3.1265  0.0049  0.6674
DN Pav
  0.4684437600    0.0000  12.550     275  0.0359
  0.4554  1.8136  0.1984  5.8583  0.1531  3.7652  0.1030  1.9233  0.0791  0.0553
  0.0573  4.5434  0.0387  2.7484  0.0244  0.9095  0.0146  5.2377  0.0092  3.0715
  0.0074  0.8278  0.0074  5.0713  0.0072  3.2198  0.0064  1.4814  0.0052  6.1221
AV Peg
  0.3903760000    0.0000  10.536     110  0.0197
  0.3487  5.7013  0.1930  1.4137  0.1084  3.6085  0.0617  5.7775  0.0379  1.5746
  0.0289  3.7197  0.0169  5.7081  0.0097  1.4041  0.0080  3.9127  0.0039  6.1281
  0.0022  2.8403  0.0022  5.2942  0.0011  1.1699  0.0011  3.0934  0.0011  5.7924
AR Per
  0.4255489200    0.0000  10.487     123  0.0112
  0.3183  2.2127  0.1725  0.7301  0.1054  5.7987  0.0610  4.5565  0.0357  3.3076
  0.0196  2.0554  0.0092  0.8390  0.0028  6.1900  0.0019  0.3446  0.0037  5.7915
  0.0046  4.5474  0.0049  3.2358  0.0044  1.8696  0.0037  0.5677  0.0028  5.5635
U Pic
  0.4403703000    0.0000  11.435     146  0.0229
  0.3892  4.8282  0.2150  5.7592  0.1431  0.8070  0.0929  2.1112  0.0577  3.4128
  0.0370  4.6538  0.0247  5.8496  0.0172  0.7516  0.0121  1.9216  0.0081  3.1289
  0.0048  4.3754  0.0022  5.6724  0.0001  1.3534  0.0016  4.9332  0.0027  6.2565
BB Pup
  0.4805468000    0.0000  12.209     290  0.0244
  0.3322  5.3753  0.1804  0.7173  0.1112  2.6217  0.0677  4.5679  0.0409  0.1003
  0.0244  1.9926  0.0138  3.9826  0.0072  6.1227  0.0037  2.2847  0.0030  4.9654
  0.0035  1.0325  0.0037  3.0668  0.0036  5.0687  0.0034  0.7098  0.0032  2.6098
V440 Sgr
  0.4774788300    0.0000  10.424     227  0.0137
  0.4214  6.2784  0.2026  2.2377  0.1530  4.8294  0.0974  1.1471  0.0721  3.8023
  0.0458  0.1497  0.0273  2.7642  0.0188  5.2133  0.0152  1.5347  0.0119  4.2220
  0.0069  0.5833  0.0044  3.1611  0.0024  5.8988  0.0016  2.0557  0.0005  4.1631
VY Ser
  0.7140962000    0.0000  10.153     254  0.0120
  0.2581  3.8357  0.1243  4.0015  0.0759  4.3823  0.0330  5.0026  0.0142  5.5430
  0.0080  0.1362  0.0071  0.9985  0.0068  1.6356  0.0061  2.1479  0.0052  2.6173
  0.0044  3.1058  0.0044  3.5220  0.0039  3.9105  0.0036  4.3377  0.0033  4.7809
AN Ser
  0.5220721100    0.0000  11.008     194  0.0177
  0.3678  3.0363  0.1834  2.4866  0.1034  2.2175  0.0626  1.7261  0.0364  1.3665
  0.0192  1.0381  0.0087  0.7593  0.0029  0.5104  0.0009  1.6616  0.0022  1.8629
  0.0037  1.4916  0.0048  1.0811  0.0055  0.7265  0.0055  0.3768  0.0050  0.1175
AT Ser
  0.7465682000    0.0000  11.531     163  0.0161
  0.3227  0.0291  0.1584  2.7672  0.1014  5.5007  0.0577  2.1541  0.0310  5.2446
  0.0166  2.1042  0.0092  5.3644  0.0060  2.5013  0.0054  5.8556  0.0052  2.7068
  0.0049  5.6932  0.0043  2.3143  0.0035  5.1647  0.0027  1.6832  0.0020  4.4269
AV Ser
  0.4875571000    0.0000  11.562     134  0.0197
  0.3988  1.5731  0.1920  5.3747  0.1341  3.3659  0.0827  1.2069  0.0519  5.3799
  0.0338  3.2693  0.0229  1.1805  0.0155  5.4071  0.0096  3.3641  0.0053  1.2870
  0.0025  5.2370  0.0016  2.5240  0.0014  0.2500  0.0011  4.6624  0.0005  3.4664
RW Tra
  0.3740390000    0.0000  11.344     168  0.0146
  0.2807  1.6469  0.1356  5.9320  0.0710  4.1350  0.0362  2.3013  0.0172  0.3859
  0.0077  4.6489  0.0032  2.5566  0.0003  0.5756  0.0013  1.7758  0.0020  0.0040
  0.0016  4.6174  0.0007  3.1526  0.0004  3.4522  0.0010  2.1761  0.0009  0.7241
W Tuc
  0.6422370000    0.0000  11.495     154  0.0088
  0.4002  5.2118  0.2145  0.3417  0.1344  2.0102  0.0886  3.9515  0.0406  5.5835
  0.0297  0.7075  0.0245  2.4465  0.0094  4.3113  0.0069  5.4001  0.0039  1.0121
  0.0012  5.7618  0.0013  2.7843  0.0017  3.4408  0.0025  4.7811  0.0030  5.7889
YY Tuc
  0.6350210000    0.0000  12.066     131  0.0206
  0.4041  1.3958  0.2203  5.1597  0.1370  2.9369  0.0886  0.9079  0.0529  5.0367
  0.0324  2.8305  0.0210  0.6233  0.0143  4.7381  0.0099  2.6492  0.0071  0.6886
  0.0055  5.1255  0.0048  3.3309  0.0046  1.5179  0.0046  5.8794  0.0043  3.8988
TU UMa
  0.5576570000    0.0000   9.849     427  0.0135
  0.3281  2.9453  0.1658  1.9827  0.1162  1.4013  0.0748  0.8343  0.0426  0.3007
  0.0236  6.0006  0.0127  5.3717  0.0064  4.7611  0.0027  4.3444  0.0015  4.8865
  0.0027  4.8732  0.0038  4.3968  0.0046  3.8138  0.0050  3.2229  0.0051  2.6125
UU Vir
  0.4756065200    0.0000  10.627     110  0.0139
  0.3756  1.3720  0.2054  5.1373  0.1310  2.9590  0.0938  0.8321  0.0569  4.9574
  0.0339  2.6308  0.0197  0.3671  0.0144  4.3542  0.0086  1.8993  0.0050  5.6799
  0.0037  3.3662  0.0046  0.6953  0.0034  4.6167  0.0018  2.0494  0.0011  5.7768
AV Vir
  0.6569080000    0.0000  11.842     140  0.0184
  0.2718  0.7286  0.1335  4.0737  0.0822  1.4576  0.0426  5.1255  0.0194  2.5043
  0.0088  0.0118  0.0056  4.2381  0.0069  2.1287  0.0078  5.9873  0.0070  3.4682
  0.0050  0.8733  0.0028  4.4377  0.0014  1.3375  0.0010  4.4196  0.0009  1.7312
FW Lup
  0.4841712000    0.0000   9.052     169  0.0086
  0.1606  3.3751  0.0634  3.1072  0.0232  3.2745  0.0082  3.6904  0.0051  4.7690
  0.0042  5.0601  0.0030  4.8525  0.0023  4.6901  0.0017  4.9176  0.0010  5.3408
  0.0003  4.9870  0.0003  2.3305  0.0003  2.6121  0.0000  5.3859  0.0003  5.5432
V490 Sco
  0.4922558000    0.0000  11.482     133  0.0195
  0.3663  1.9254  0.2038  0.1110  0.1250  4.7910  0.0820  3.3398  0.0380  1.7193
  0.0338  6.0684  0.0220  4.7434  0.0086  2.8546  0.0088  1.5222  0.0058  1.3098
  0.0045  6.0720  0.0009  4.5418  0.0076  3.7729  0.0022  1.8668  0.0025  1.0862
AF Vel
  0.5273984000    0.0000  11.482     157  0.0239
  0.3759  5.8477  0.1376  1.3938  0.0933  3.4968  0.0617  5.6998  0.0358  1.6889
  0.0195  3.8089  0.0103  5.5790  0.0091  1.0873  0.0071  3.2653  0.0040  5.4608
  0.0015  0.5806  0.0026  2.0800  0.0024  4.6055  0.0003  0.2005  0.0019  0.9708
UU Cet
  0.6060721000    0.0000  12.096     237  0.0191
  0.2375  4.6102  0.1090  5.4051  0.0693  0.3343  0.0392  1.7366  0.0139  3.1655
  0.0050  5.1573  0.0050  0.6754  0.0055  1.7681  0.0059  2.6917  0.0059  3.6384
  0.0054  4.6505  0.0043  5.7439  0.0032  0.6904  0.0024  2.1088  0.0022  3.5242
S Ara
  0.4518795000    0.0000  10.847     335  0.0175
  0.4389  1.1536  0.2113  4.5513  0.1647  1.9809  0.1062  5.7515  0.0777  3.1931
  0.0497  0.6987  0.0270  4.3402  0.0219  1.7162  0.0159  5.4500  0.0098  3.1381
  0.0079  0.2860  0.0064  4.1626  0.0045  1.4240  0.0029  4.8622  0.0019  2.4384
V675 Sgr
  0.6422895000    0.0000  10.394     237  0.0152
  0.3255  4.1899  0.1532  4.4373  0.1171  5.0077  0.0757  5.6205  0.0486  6.2605
  0.0235  0.6508  0.0093  1.1960  0.0071  1.4745  0.0066  2.7387  0.0072  3.9962
  0.0059  5.4567  0.0021  0.3332  0.0036  0.1265  0.0035  1.0168  0.0045  1.3120
AA CMi
  0.4763239000    0.0000  11.571      76  0.0122
  0.3614  4.0322  0.1830  4.4886  0.1027  5.2535  0.0601  5.9087  0.0351  0.2690
  0.0201  0.8712  0.0113  1.4164  0.0063  1.9319  0.0033  2.5146  0.0012  3.4517
  0.0010  5.8352  0.0020  0.6689  0.0025  1.4800  0.0025  2.2539  0.0020  3.0228
V690 Sco
  0.4922551000    0.0000  11.483     151  0.0234
  0.3608  1.1773  0.2030  4.9002  0.1253  2.5389  0.0809  0.3401  0.0442  4.1992
  0.0278  1.6788  0.0187  5.5480  0.0114  3.3146  0.0056  1.3139  0.0031  6.0502
  0.0029  4.3494  0.0027  2.0394  0.0024  5.7720  0.0022  3.1689  0.0019  0.7607
V964 Ori
  0.5046350000    0.0000  13.067      75  0.0136
  0.4331  1.1143  0.1942  4.4287  0.1504  1.7296  0.0949  5.5227  0.0687  2.9308
  0.0504  0.3918  0.0321  4.1086  0.0207  1.4755  0.0145  5.0802  0.0109  2.4187
  0.0083  6.1038  0.0063  3.5876  0.0045  1.1660  0.0033  5.1323  0.0025  2.8974
VW Scl
  0.5109147000    0.0000  11.111      47  0.0092
  0.4462  0.3364  0.2139  2.9227  0.1338  5.9395  0.0982  2.6548  0.0599  5.6900
  0.0377  2.3342  0.0258  5.1996  0.0188  1.7916  0.0137  4.7042  0.0094  1.3535
  0.0058  4.2566  0.0030  0.7147  0.0017  2.9351  0.0020  5.1952  0.0023  1.6978
AQ Lyr
  0.3571424000    0.0000  13.053      58  0.0152
  0.3878  2.8487  0.1939  1.8247  0.0918  1.0658  0.0593  0.2955  0.0343  5.6907
  0.0211  4.8685  0.0132  4.0290  0.0096  3.1134  0.0086  2.2567  0.0081  1.5318
  0.0069  0.8859  0.0051  0.2696  0.0029  5.9380  0.0007  5.2550  0.0010  1.6842
CN Lyr
  0.4113823200    0.0000  11.386      52  0.0062
  0.2124  6.0931  0.0874  2.2332  0.0381  4.9616  0.0153  1.2542  0.0059  3.5135
  0.0028  5.5678  0.0012  1.1971  0.0010  2.6793  0.0010  4.9696  0.0004  1.1102
  0.0004  1.4044  0.0007  3.9774  0.0005  0.3206  0.0002  1.4226  0.0006  3.3792
M2 V3
  0.6197084000    0.0000  16.009     142  0.0115
  0.3620  4.2297  0.1866  4.6589  0.1199  5.3151  0.0805  6.1052  0.0430  0.6573
  0.0221  1.0830  0.0156  1.8186  0.0096  2.6539  0.0047  3.5039  0.0017  4.5117
  0.0008  0.0956  0.0013  1.3157  0.0018  2.0252  0.0022  2.7023  0.0024  3.4196
M2 V4
  0.5642512000    0.0000  15.970     141  0.0249
  0.3491  3.5961  0.1651  3.0857  0.1208  2.9443  0.0868  2.9134  0.0550  2.8421
  0.0266  2.6881  0.0200  2.4107  0.0173  2.3543  0.0131  2.4038  0.0083  2.4895
  0.0043  2.6136  0.0017  2.8515  0.0007  3.3618  0.0005  3.3334  0.0010  2.8721
M2 V7
  0.5948665000    0.0000  16.003     145  0.0167
  0.3738  4.7682  0.1817  5.6607  0.1207  0.5681  0.0775  1.7928  0.0449  3.0318
  0.0213  4.1222  0.0099  5.0251  0.0054  5.9052  0.0030  0.7444  0.0012  2.3465
  0.0009  4.9887  0.0014  0.4727  0.0015  1.8936  0.0012  3.2480  0.0007  4.5840
M2 V9
  0.6092938000    0.0000  16.045     145  0.0115
  0.3496  1.3511  0.1762  5.1069  0.1182  2.9054  0.0781  0.7729  0.0458  4.9202
  0.0215  2.7277  0.0150  0.3543  0.0109  4.4957  0.0063  2.5514  0.0029  0.9247
  0.0018  6.0908  0.0019  4.4769  0.0016  2.3511  0.0013  6.1432  0.0015  3.5975
M2 V10
  0.8757413000    0.0000  15.752     145  0.0084
  0.2514  4.8819  0.1052  0.1187  0.0483  2.0391  0.0202  3.5895  0.0095  5.9780
  0.0086  2.1964  0.0066  3.8314  0.0063  5.4206  0.0056  0.6613  0.0045  2.2050
  0.0035  3.8213  0.0028  5.4608  0.0022  0.7402  0.0016  2.1524  0.0011  3.3995
M2 V12
  0.6656063000    0.0000  15.954     145  0.0170
  0.3546  2.1568  0.1918  0.6000  0.1244  5.5326  0.0737  4.4101  0.0392  3.0618
  0.0243  1.6336  0.0164  0.5288  0.0053  5.8080  0.0045  3.5438  0.0017  3.8396
  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000
M2 V13
  0.7066260000    0.0000  15.950     145  0.0151
  0.2870  4.6741  0.1497  5.6776  0.0928  0.5871  0.0401  1.9603  0.0206  3.4534
  0.0113  5.0845  0.0074  0.6102  0.0067  2.3231  0.0065  3.7713  0.0060  5.0404
  0.0054  6.2096  0.0049  1.0598  0.0045  2.2166  0.0041  3.4336  0.0037  4.7194
M3 V01
  0.5206250000    0.0000  15.690     169  0.0130
  0.3973  1.7451  0.1707  5.7437  0.1365  3.6364  0.0920  1.7301  0.0667  6.1092
  0.0458  4.1882  0.0289  2.3777  0.0151  0.5107  0.0092  4.8520  0.0069  2.7673
  0.0071  0.8802  0.0057  5.3630  0.0011  3.7321  0.0019  2.8230  0.0020  0.3741
M3 V10
  0.5695185000    0.0000  15.680     173  0.0151
  0.3153  2.2330  0.1434  0.4995  0.1100  5.3674  0.0684  4.0358  0.0416  2.7675
  0.0218  1.5238  0.0081  0.1176  0.0041  4.6785  0.0045  3.4445  0.0043  3.4406
  0.0037  2.7429  0.0016  1.5737  0.0028  0.1757  0.0015  4.0226  0.0008  4.3968
M3 V11
  0.5078918000    0.0000  15.694     170  0.0099
  0.4278  1.1862  0.1920  4.6375  0.1486  2.0498  0.0982  5.8793  0.0725  3.4067
  0.0521  1.0130  0.0337  4.8688  0.0202  2.3736  0.0155  6.0733  0.0125  3.5169
  0.0094  0.9681  0.0050  4.4099  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000
M3 V14
  0.6359019000    0.0000  15.565     168  0.0150
  0.3032  5.4509  0.1506  0.8182  0.0907  2.7822  0.0547  4.8675  0.0212  0.6129
  0.0099  2.2500  0.0048  4.4235  0.0032  1.8534  0.0040  4.8665  0.0039  0.3559
  0.0042  2.3375  0.0040  4.1098  0.0029  6.2115  0.0030  1.4998  0.0020  3.5082
M3 V15
  0.5300794000    0.0000  15.668     169  0.0095
  0.3719  3.0818  0.1660  2.1272  0.1328  1.4305  0.0895  0.8772  0.0632  0.3278
  0.0418  6.0982  0.0241  5.6115  0.0142  4.8343  0.0110  4.1856  0.0082  3.4594
  0.0058  3.0682  0.0039  2.8098  0.0030  2.5766  0.0016  3.4055  0.0025  2.0192
M3 V17
  0.5757000000    0.0000  15.694     166  0.0149
  0.2683  3.4985  0.1128  3.0558  0.0766  2.9144  0.0363  2.8320  0.0122  2.7280
  0.0017  2.2546  0.0024  6.1712  0.0031  6.0560  0.0026  6.0803  0.0021  6.2081
  0.0017  0.1385  0.0017  0.3295  0.0017  0.4262  0.0015  0.4495  0.0012  0.4263
M3 V18
  0.5163623000    0.0000  15.754     168  0.0156
  0.3795  4.4216  0.1766  4.8266  0.1382  5.5440  0.0923  0.0334  0.0641  0.8163
  0.0379  1.6732  0.0215  2.5011  0.0154  3.0727  0.0116  3.6966  0.0089  4.5914
  0.0044  5.6303  0.0037  1.4058  0.0026  1.8685  0.0014  3.5457  0.0038  4.0819
M3 V23
  0.5953756000    0.0000  15.634     172  0.0158
  0.2745  0.1664  0.1241  2.7549  0.0800  5.6515  0.0440  2.4177  0.0209  5.5595
  0.0087  2.4002  0.0029  5.6278  0.0011  3.1370  0.0012  0.1393  0.0017  2.7846
  0.0023  5.5154  0.0028  2.1151  0.0030  5.0995  0.0028  1.8902  0.0024  5.0696
M3 V34
  0.5591012000    0.0000  15.675     174  0.0157
  0.3601  5.9070  0.1677  1.6976  0.1049  3.9299  0.0543  6.1002  0.0331  1.8509
  0.0203  3.8831  0.0140  6.0803  0.0094  1.8301  0.0068  3.8231  0.0033  5.9114
  0.0027  2.6979  0.0022  3.9663  0.0011  1.3098  0.0004  5.1095  0.0010  1.1808
M3 V35
  0.5296000000    0.0000  15.657     167  0.0215
  0.4227  1.6229  0.1939  5.5149  0.1314  3.3665  0.0848  1.3830  0.0567  5.6704
  0.0371  3.6858  0.0234  1.7164  0.0143  6.0482  0.0089  4.1108  0.0059  2.1612
  0.0044  0.1546  0.0037  4.3596  0.0034  2.2388  0.0030  0.0961  0.0025  4.1995
M3 V50
  0.5130879000    0.0000  15.686     171  0.0160
  0.2425  1.7124  0.0860  5.6058  0.0347  3.2370  0.0081  1.2413  0.0050  5.7063
  0.0017  3.3751  0.0009  0.8362  0.0012  3.5564  0.0016  3.3862  0.0018  1.1521
  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000
M3 V51
  0.5839818000    0.0000  15.691     171  0.0103
  0.2854  3.0809  0.1384  2.2614  0.0994  1.8002  0.0614  1.4038  0.0337  1.1239
  0.0124  0.7361  0.0064  0.2302  0.0032  0.2477  0.0055  0.8273  0.0055  0.6411
  0.0053  0.1894  0.0058  5.8316  0.0046  5.6502  0.0056  5.2393  0.0045  4.9646
M3 V52
  0.5162250000    0.0000  15.706     174  0.0152
  0.4421  3.2691  0.1811  2.5612  0.1412  1.9627  0.0922  1.4479  0.0660  0.9424
  0.0458  0.5202  0.0301  0.0722  0.0216  5.8443  0.0174  5.4065  0.0113  5.0284
  0.0091  4.5779  0.0061  4.1685  0.0039  3.6139  0.0030  3.1737  0.0026  3.0758
M3 V53
  0.5048878000    0.0000  15.736     175  0.0133
  0.4045  4.4816  0.1873  4.8783  0.1415  5.5529  0.0977  0.0913  0.0667  0.9092
  0.0452  1.7156  0.0304  2.5020  0.0201  3.2587  0.0131  3.9768  0.0087  4.6568
  0.0059  5.3255  0.0042  6.0423  0.0030  0.5962  0.0022  1.6220  0.0019  2.8469
M3 V59
  0.5888053000    0.0000  15.685     168  0.0159
  0.3016  2.7599  0.1391  1.6705  0.0944  0.8470  0.0551  0.0738  0.0261  5.6276
  0.0109  4.8789  0.0035  4.1761  0.0008  5.0026  0.0024  5.0198  0.0036  4.2341
  0.0044  3.4097  0.0049  2.5924  0.0050  1.7840  0.0048  0.9779  0.0044  0.1662
M3 V61
  0.5209312000    0.0000  15.701     172  0.0122
  0.4528  5.6716  0.1973  1.0443  0.1281  2.9030  0.0908  4.9514  0.0624  0.6971
  0.0435  2.7173  0.0308  4.7289  0.0221  0.4474  0.0160  2.4387  0.0118  4.4220
  0.0087  0.1210  0.0065  2.1140  0.0050  4.1344  0.0038  6.2011  0.0030  2.0480
M3 V62
  0.6524077000    0.0000  15.631     173  0.0133
  0.1830  0.2666  0.0842  3.1265  0.0449  0.1401  0.0210  3.5948  0.0092  0.8479
  0.0062  4.6286  0.0058  1.8669  0.0053  5.1794  0.0044  2.1252  0.0035  5.3034
  0.0027  2.1451  0.0021  5.2123  0.0018  1.9628  0.0017  5.0144  0.0016  1.8327
M3 V64
  0.6054588000    0.0000  15.697     174  0.0130
  0.2501  5.0062  0.1159  6.2325  0.0770  1.5420  0.0435  3.2444  0.0187  5.0715
  0.0073  0.5026  0.0045  2.6796  0.0049  4.9228  0.0075  0.2889  0.0073  2.0871
  0.0068  3.2099  0.0059  4.6444  0.0043  0.0274  0.0038  1.2585  0.0021  3.3002
M3 V65
  0.6683397000    0.0000  15.534     165  0.0099
  0.3238  3.8356  0.1658  3.9646  0.1031  4.2637  0.0585  4.8071  0.0291  5.1055
  0.0173  5.4878  0.0060  6.2427  0.0031  1.1576  0.0030  2.0870  0.0037  2.7712
  0.0047  3.2736  0.0056  3.6549  0.0060  3.9668  0.0059  4.2357  0.0055  4.4791
M3 V69
  0.5665878000    0.0000  15.701     175  0.0109
  0.3038  2.7876  0.1469  1.6229  0.1070  0.8347  0.0681  0.1301  0.0377  5.7276
  0.0179  4.9419  0.0083  3.9769  0.0058  3.7840  0.0046  3.4630  0.0047  3.6681
  0.0048  2.7571  0.0045  2.3068  0.0057  1.1729  0.0044  0.7299  0.0057  5.9732
M3 V74
  0.4921441000    0.0000  15.724     174  0.0109
  0.4279  5.1452  0.1873  6.2828  0.1485  1.3142  0.0993  2.8245  0.0697  4.3385
  0.0474  5.8705  0.0305  1.0708  0.0202  2.5408  0.0125  3.8033  0.0123  5.1815
  0.0085  0.5387  0.0062  2.1231  0.0044  3.7646  0.0039  5.5608  0.0012  1.1627
M3 V84
  0.5957289000    0.0000  15.673     173  0.0082
  0.2543  4.7703  0.1207  5.6610  0.0851  0.6864  0.0472  2.0592  0.0221  3.5365
  0.0079  4.9300  0.0059  0.6969  0.0058  2.3028  0.0061  3.8528  0.0075  5.3554
  0.0064  0.3091  0.0054  1.4430  0.0050  3.0326  0.0036  4.5186  0.0029  5.4709
M3 V90
  0.5170334000    0.0000  15.731     168  0.0171
  0.3840  2.9636  0.1766  1.8905  0.1382  1.1183  0.0920  0.4024  0.0664  5.9781
  0.0405  5.3829  0.0247  4.7576  0.0143  3.9080  0.0118  3.0555  0.0087  2.5946
  0.0047  2.0845  0.0026  1.2568  0.0016  0.0747  0.0005  2.7633  0.0015  0.0311
M3 V92
  0.5035553000    0.0000  15.720     166  0.0100
  0.3941  4.8920  0.1542  5.6389  0.1106  0.3661  0.0706  1.5298  0.0452  2.6873
  0.0279  3.9832  0.0150  5.4009  0.0080  0.7525  0.0046  2.6087  0.0023  3.7180
  0.0038  4.4337  0.0041  5.9020  0.0021  0.8317  0.0015  1.0039  0.0018  2.0852
M3 V104
  0.5699231000    0.0000  15.603     174  0.0122
  0.4233  5.7721  0.2043  1.2905  0.1475  3.2939  0.1023  5.4185  0.0742  1.3983
  0.0469  3.6420  0.0274  5.5997  0.0201  1.3036  0.0160  3.4867  0.0124  5.7831
  0.0091  1.8410  0.0065  4.1988  0.0045  0.2757  0.0033  2.6162  0.0026  4.9049
M3 V106
  0.5471593000    0.0000  15.718     174  0.0158
  0.2342  0.2838  0.1207  3.1699  0.0622  6.2290  0.0176  2.8458  0.0016  6.2337
  0.0039  5.5276  0.0048  2.4583  0.0042  5.7354  0.0033  2.8282  0.0026  6.2678
  0.0021  3.4147  0.0017  0.5148  0.0013  3.8603  0.0009  0.9020  0.0006  4.2167
M3 V124
  0.7524328000    0.0000  15.542     169  0.0063
  0.1481  5.4735  0.0493  1.1354  0.0192  3.5213  0.0050  6.2363  0.0043  2.7882
  0.0049  4.8196  0.0036  0.9260  0.0034  3.2890  0.0017  5.3338  0.0015  0.8265
  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000
M5 V1
  0.5217770000    0.0000  15.158     243  0.0102
  0.3681  2.4975  0.1827  1.0512  0.1307  6.2184  0.0876  5.0860  0.0554  4.0946
  0.0318  2.9942  0.0213  1.6837  0.0155  0.4497  0.0104  5.6050  0.0058  4.5243
  0.0024  3.4431  0.0003  2.1258  0.0007  4.5963  0.0010  3.4076  0.0008  2.1496
M5 V2
  0.5266120000    0.0000  15.141     274  0.0273
  0.3975  1.5053  0.1978  5.4245  0.1132  3.2813  0.0824  1.1330  0.0547  5.2633
  0.0372  3.0707  0.0268  0.8524  0.0203  4.9132  0.0158  2.7008  0.0125  0.4997
  0.0098  4.5838  0.0076  2.3706  0.0059  0.1251  0.0046  4.1186  0.0038  1.7985
M5 V3
  0.6001490000    0.0000  15.077     272  0.0112
  0.2531  5.8995  0.1212  1.6979  0.0786  4.1641  0.0435  0.4649  0.0192  3.1139
  0.0068  5.6615  0.0052  2.6670  0.0063  5.4871  0.0065  1.8302  0.0061  4.3859
  0.0054  0.5848  0.0046  2.9981  0.0038  5.3698  0.0032  1.4626  0.0027  3.8861
M5 V4
  0.4496990000    0.0000  15.098     264  0.0249
  0.3923  1.7921  0.1669  5.9430  0.0816  3.8809  0.0366  2.0876  0.0136  0.1710
  0.0036  3.5419  0.0061  0.5897  0.0071  4.8865  0.0056  2.9765  0.0031  0.9502
  0.0014  4.4376  0.0022  1.5759  0.0031  5.8202  0.0031  3.9233  0.0025  2.0385
M5 V5
  0.5458240000    0.0000  15.130     266  0.0348
  0.3505  1.0638  0.1675  4.3566  0.1295  1.9415  0.0866  5.7582  0.0514  3.1862
  0.0290  0.7367  0.0173  4.3580  0.0115  1.7761  0.0070  5.6660  0.0034  3.5830
  0.0023  2.1443  0.0032  0.2216  0.0038  4.0982  0.0040  1.5144  0.0041  5.1419
M5 V8
  0.5461430000    0.0000  15.128     274  0.0174
  0.3408  6.0358  0.1550  1.8697  0.1100  4.2976  0.0697  0.4963  0.0411  2.9696
  0.0235  5.3787  0.0130  1.4293  0.0069  3.6782  0.0032  5.8082  0.0011  1.1379
  0.0015  1.9666  0.0028  4.0344  0.0037  0.0806  0.0041  2.4908  0.0040  4.9380
M5 V9
  0.6989070000    0.0000  14.929     274  0.0118
  0.2854  5.8256  0.1412  1.8389  0.0864  4.3027  0.0358  0.5288  0.0219  3.1497
  0.0067  6.2139  0.0046  2.8382  0.0064  5.7954  0.0067  2.2484  0.0055  4.3114
  0.0062  0.5081  0.0068  3.2232  0.0049  5.8084  0.0049  1.4521  0.0044  4.3489
M5 V10
  0.5306620000    0.0000  15.132     140  0.0118
  0.3652  5.4472  0.1781  0.6174  0.1319  2.4297  0.0854  4.2506  0.0557  6.1620
  0.0308  1.7558  0.0171  3.4476  0.0123  5.1818  0.0089  0.7610  0.0051  2.7141
  0.0018  5.0175  0.0018  2.3577  0.0033  4.5088  0.0040  0.0914  0.0042  1.8960
M5 V11
  0.5959110000    0.0000  14.988     240  0.0137
  0.3807  0.1909  0.2017  2.8334  0.1249  5.7556  0.0874  2.4989  0.0483  5.5742
  0.0268  1.9554  0.0186  4.9299  0.0120  1.7282  0.0069  4.7937  0.0034  1.5439
  0.0013  4.6247  0.0003  2.5754  0.0009  0.1189  0.0013  3.0542  0.0017  5.9318
M5 V12
  0.4677070000    0.0000  15.168     275  0.0109
  0.4412  6.2654  0.2028  2.1968  0.1566  4.7166  0.1000  1.0719  0.0702  3.6208
  0.0499  0.0078  0.0321  2.6055  0.0212  5.1306  0.0151  1.3388  0.0115  3.8471
  0.0090  0.1145  0.0069  2.7080  0.0051  5.3409  0.0035  1.7364  0.0021  4.4981
M5 V16
  0.6476340000    0.0000  14.868     270  0.0154
  0.3991  0.1464  0.2204  2.8597  0.1352  5.6662  0.0871  2.5690  0.0402  5.4332
  0.0361  1.8768  0.0217  4.8574  0.0108  1.5221  0.0055  4.3061  0.0034  0.7337
  0.0022  3.6322  0.0011  0.6202  0.0007  5.2007  0.0017  2.5209  0.0024  5.6635
M5 V19
  0.4699180000    0.0000  15.176     270  0.0300
  0.4855  5.8218  0.2046  1.3971  0.1531  3.2950  0.1089  5.4125  0.0797  1.1838
  0.0613  3.3087  0.0416  5.5134  0.0302  1.3891  0.0174  3.4264  0.0128  5.2706
  0.0119  1.0276  0.0101  3.3221  0.0059  5.5912  0.0034  0.9456  0.0036  2.8710
M5 V20
  0.6095510000    0.0000  15.059     272  0.0258
  0.3187  4.7751  0.1610  5.7656  0.1016  0.7428  0.0615  2.2715  0.0323  3.5971
  0.0209  4.6524  0.0084  6.1314  0.0031  2.2926  0.0044  4.4260  0.0054  5.8369
  0.0060  0.8357  0.0065  2.1106  0.0068  3.4064  0.0067  4.7178  0.0064  6.0320
M5 V21
  0.6048960000    0.0000  15.043     275  0.0120
  0.3310  2.8505  0.1790  1.9069  0.1142  1.2115  0.0694  0.6728  0.0362  0.0427
  0.0185  5.3408  0.0095  4.9791  0.0052  5.0050  0.0041  5.2151  0.0047  5.0539
  0.0052  4.5177  0.0051  3.8126  0.0047  3.0510  0.0042  2.3084  0.0036  1.6386
M5 V28
  0.5438650000    0.0000  15.125     275  0.0201
  0.3199  4.8673  0.1576  5.8060  0.1055  0.8217  0.0648  2.1479  0.0375  3.5770
  0.0147  4.8513  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000
  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000
M5 V29
  0.4513320000    0.0000  15.165     265  0.0138
  0.3593  5.9633  0.1311  1.5951  0.0627  3.5386  0.0262  5.0603  0.0180  0.6210
  0.0122  2.3934  0.0093  4.4563  0.0047  0.2969  0.0027  1.6277  0.0034  3.5847
  0.0025  5.9900  0.0008  1.7962  0.0009  2.5779  0.0012  4.9032  0.0007  1.0132
M5 V30
  0.5922070000    0.0000  15.094     101  0.0094
  0.2769  4.5570  0.1369  5.2568  0.0980  0.1042  0.0579  1.2324  0.0306  2.4930
  0.0165  3.5274  0.0078  4.4726  0.0036  6.1271  0.0048  1.8103  0.0064  3.0907
  0.0065  4.1919  0.0056  5.2186  0.0044  6.1844  0.0033  0.8194  0.0025  1.7386
M5 V32
  0.4577970000    0.0000  15.148     274  0.0104
  0.4505  1.4036  0.2078  5.0440  0.1573  2.6321  0.1029  0.3693  0.0700  4.3512
  0.0502  2.0992  0.0318  6.1112  0.0204  3.7677  0.0144  1.3557  0.0114  5.2241
  0.0096  2.8586  0.0080  0.5446  0.0064  4.5496  0.0048  2.2950  0.0034  0.0612
M5 V34
  0.5681190000    0.0000  15.075     263  0.0218
  0.2884  0.4814  0.1338  3.2490  0.0990  0.1996  0.0578  3.6277  0.0312  0.5885
  0.0162  3.8180  0.0058  0.7489  0.0022  4.9944  0.0043  2.6061  0.0058  5.8904
  0.0062  2.8415  0.0058  6.0760  0.0050  3.0286  0.0041  6.2581  0.0034  3.1915
M5 V38
  0.4704370000    0.0000  15.129     236  0.0220
  0.3413  2.5290  0.1504  1.2720  0.0833  0.2184  0.0537  5.6020  0.0294  4.5139
  0.0199  3.3769  0.0148  2.3898  0.0100  1.5123  0.0055  0.6447  0.0018  5.7704
  0.0016  3.1635  0.0029  2.0908  0.0033  1.3069  0.0028  0.5988  0.0019  6.2554
M5 V39
  0.5890350000    0.0000  14.999     237  0.0106
  0.3892  0.4170  0.2037  3.2638  0.1295  0.1426  0.0932  3.3379  0.0534  0.3717
  0.0300  3.3486  0.0214  0.1437  0.0143  3.2929  0.0078  0.1837  0.0028  3.4822
  0.0011  2.2192  0.0027  5.8567  0.0034  2.6808  0.0034  5.7046  0.0030  2.4080
M5 V43
  0.6601770000    0.0000  15.042     243  0.0088
  0.2251  3.2338  0.1020  2.8338  0.0598  2.6839  0.0254  2.7889  0.0105  2.9216
  0.0066  3.1790  0.0067  3.5642  0.0078  3.5116  0.0075  3.4196  0.0062  3.3195
  0.0049  3.1677  0.0039  2.9546  0.0032  2.7270  0.0026  2.5300  0.0020  2.3595
M5 V45
  0.6166320000    0.0000  15.009     133  0.0207
  0.3253  5.6882  0.1731  1.2289  0.1152  3.5124  0.0737  5.6984  0.0468  1.5357
  0.0285  3.5984  0.0162  5.6533  0.0080  1.4838  0.0029  3.9229  0.0021  1.1989
  0.0036  3.7041  0.0043  5.8570  0.0042  1.6649  0.0036  3.7485  0.0028  5.8604
M5 V47
  0.5397390000    0.0000  15.145     134  0.0229
  0.3460  6.1634  0.1572  2.0629  0.1242  4.6051  0.0827  0.9388  0.0525  3.6704
  0.0333  6.2649  0.0210  2.4500  0.0134  4.8257  0.0086  0.8653  0.0054  3.1572
  0.0029  5.3530  0.0014  0.7631  0.0019  2.1734  0.0029  4.3401  0.0036  0.4560
M5 V52
  0.5017850000    0.0000  15.005     134  0.0228
  0.3991  2.4126  0.1838  0.8144  0.0858  5.6386  0.0412  3.8224  0.0379  1.9453
  0.0260  0.7015  0.0119  5.0760  0.0153  2.9899  0.0160  1.5863  0.0113  0.1438
  0.0071  4.6515  0.0057  2.7479  0.0046  0.9518  0.0037  5.2925  0.0037  3.3767
M5 V56
  0.5348490000    0.0000  15.135     240  0.0109
  0.2537  6.2668  0.0986  2.3364  0.0557  5.3493  0.0249  2.2683  0.0150  5.5367
  0.0073  2.8763  0.0078  6.0436  0.0045  2.1519  0.0032  4.6403  0.0029  1.3590
  0.0027  4.4059  0.0022  1.0516  0.0015  3.9564  0.0011  0.6380  0.0009  3.6133
M5 V59
  0.5420270000    0.0000  14.991     274  0.0153
  0.3240  6.2617  0.1642  2.2856  0.1125  4.9853  0.0770  1.3794  0.0460  4.1745
  0.0249  0.5586  0.0152  3.0488  0.0097  5.7187  0.0053  2.3404  0.0027  5.6532
  0.0025  2.9368  0.0032  5.9848  0.0037  2.4944  0.0040  5.2217  0.0041  1.6591
M5 V61
  0.5686470000    0.0000  15.095     274  0.0101
  0.3122  0.8746  0.1570  4.1406  0.1066  1.4941  0.0680  5.1606  0.0366  2.6230
  0.0192  6.1722  0.0106  3.5396  0.0056  1.1451  0.0033  5.4561  0.0034  3.5389
  0.0041  1.2094  0.0044  4.9519  0.0045  2.3133  0.0044  5.9024  0.0042  3.1787
M5 V64
  0.5444920000    0.0000  15.133     240  0.0101
  0.3382  6.2089  0.1698  2.1967  0.1238  4.7968  0.0804  1.1645  0.0512  3.9598
  0.0325  0.4273  0.0206  2.9383  0.0157  5.3968  0.0104  1.9207  0.0080  4.6713
  0.0041  0.9797  0.0024  3.4405  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000
M5 V75
  0.6854710000    0.0000  15.002     137  0.0111
  0.2088  1.1295  0.0920  4.9546  0.0471  2.7441  0.0175  0.8722  0.0091  5.6677
  0.0099  4.0216  0.0069  1.6177  0.0070  5.7577  0.0063  3.9996  0.0043  1.4973
  0.0040  5.5726  0.0031  3.7573  0.0033  1.2768  0.0018  5.3313  0.0019  2.1901
M5 V77
  0.8452610000    0.0000  14.773     273  0.0099
  0.2324  4.8288  0.0944  0.0590  0.0394  2.0334  0.0190  4.0547  0.0119  6.2330
  0.0108  1.9309  0.0099  3.6102  0.0082  5.1408  0.0061  0.3258  0.0041  1.7958
  0.0026  3.3654  0.0017  5.1819  0.0015  0.8609  0.0015  2.5954  0.0013  4.1049
M5 V81
  0.5572920000    0.0000  15.091     272  0.0200
  0.3141  1.0147  0.1588  4.3528  0.1125  1.8491  0.0695  5.6250  0.0420  3.0914
  0.0245  0.5238  0.0131  4.2469  0.0059  1.7995  0.0022  0.0436  0.0032  4.8438
  0.0049  2.4679  0.0058  6.2129  0.0061  3.6451  0.0060  1.0793  0.0056  4.8107
M5 V82
  0.5589270000    0.0000  15.058     125  0.0214
  0.2991  0.4023  0.1617  3.2830  0.1135  0.1290  0.0685  3.3918  0.0394  0.2932
  0.0227  3.5117  0.0132  0.5393  0.0080  4.0022  0.0057  1.3244  0.0051  4.9068
  0.0048  2.0932  0.0046  5.4997  0.0042  2.6206  0.0039  6.0520  0.0038  3.2128
M5 V87
  0.7392100000    0.0000  14.922     270  0.0069
  0.1498  1.1001  0.0535  5.0502  0.0201  3.0278  0.0074  1.4769  0.0068  0.0738
  0.0031  3.5032  0.0052  1.8439  0.0019  5.8333  0.0015  3.0156  0.0011  0.7366
  0.0008  4.4924  0.0020  4.1917  0.0007  1.5445  0.0017  5.3201  0.0005  4.5176
M5 V89
  0.5584540000    0.0000  15.120     259  0.0256
  0.3157  2.1510  0.1546  0.2552  0.1199  5.1342  0.0708  3.8139  0.0395  2.2854
  0.0229  0.7677  0.0124  5.6061  0.0056  4.2762  0.0017  3.5280  0.0022  3.5083
  0.0034  2.2885  0.0041  0.8636  0.0044  5.6852  0.0045  4.2301  0.0044  2.7967
M5 V27
  0.4703360000    0.0000  15.054     260  0.0251
  0.4099  0.8144  0.1941  3.5989  0.1495  0.6548  0.0800  4.0561  0.0486  0.9972
  0.0284  4.1920  0.0147  1.1271  0.0064  4.3899  0.0019  1.3899  0.0001  4.7066
  0.0004  0.2619  0.0013  3.9751  0.0022  1.0656  0.0027  4.3491  0.0026  1.3639
M5 V33
  0.5014770000    0.0000  15.133     260  0.0146
  0.3938  4.8828  0.1821  5.7408  0.1397  0.6006  0.0944  1.8337  0.0671  3.0320
  0.0431  4.3216  0.0257  5.5949  0.0135  0.3752  0.0112  1.3880  0.0076  2.8500
  0.0041  4.4349  0.0020  0.3384  0.0008  2.6614  0.0015  4.4283  0.0011  0.1349
M5 V83
  0.5532900000    0.0000  15.125     116  0.0206
  0.2984  1.7035  0.1523  5.6638  0.1022  3.9309  0.0653  2.1010  0.0395  0.2680
  0.0220  4.7466  0.0110  3.0327  0.0054  1.5350  0.0037  0.2744  0.0037  5.0018
  0.0036  3.3770  0.0043  1.6577  0.0042  6.1238  0.0039  4.3398  0.0033  2.4989
M5 V91
  0.6013850000    0.0000  15.003     250  0.0302
  0.3927  4.3209  0.2073  4.8151  0.1361  5.5215  0.0955  0.2462  0.0528  1.0413
  0.0306  1.6963  0.0246  2.5236  0.0146  3.4465  0.0090  4.1364  0.0028  4.2496
  0.0041  0.3537  0.0044  1.5016  0.0037  2.6339  0.0021  2.9153  0.0031  5.2479
M9 V1
  0.5857280000    0.0000  16.233     132  0.0160
  0.4052  0.4556  0.1902  3.1878  0.1387  0.0342  0.0926  3.0927  0.0637  0.0258
  0.0313  3.3038  0.0140  6.1700  0.0093  2.6606  0.0066  5.6276  0.0040  2.5175
  0.0021  6.0791  0.0019  3.7868  0.0025  1.0083  0.0028  4.2116  0.0028  1.0328
M9 V4
  0.6713300000    0.0000  16.084     164  0.0214
  0.3210  4.5307  0.1695  5.1747  0.1003  6.0745  0.0718  1.0077  0.0322  2.0049
  0.0138  2.5097  0.0095  3.6734  0.0045  5.1446  0.0020  1.2677  0.0029  3.2066
  0.0028  4.4548  0.0016  5.4455  0.0007  5.3711  0.0015  5.4599  0.0021  0.1456
M9 V6
  0.6077950000    0.0000  16.199     163  0.0274
  0.3314  0.4608  0.1589  3.2022  0.1153  6.2317  0.0821  3.0010  0.0511  6.2773
  0.0241  3.2001  0.0147  5.7215  0.0143  2.4291  0.0112  5.6747  0.0066  2.6015
  0.0025  5.4384  0.0021  0.8021  0.0035  3.6255  0.0037  0.4442  0.0031  3.5523
M55 V1
  0.5799780000    0.0000  14.446     744  0.0141
  0.4394  4.8053  0.2104  5.6259  0.1478  0.5352  0.0983  1.6519  0.0704  2.9369
  0.0413  4.2560  0.0264  5.2459  0.0203  0.0039  0.0153  1.2007  0.0106  2.4759
  0.0067  3.7787  0.0040  5.0876  0.0024  0.1229  0.0015  1.4897  0.0012  2.9447
M55 V3
  0.6619870000    0.0000  14.316     762  0.0125
  0.3584  2.2442  0.1443  0.6548  0.0664  5.4540  0.0311  4.1698  0.0124  2.5035
  0.0080  0.9961  0.0040  5.2076  0.0022  3.3649  0.0014  1.5645  0.0012  5.9050
  0.0015  4.1065  0.0018  2.6525  0.0015  1.3901  0.0008  0.3537  0.0004  0.7776
M55 V7
  0.6825730000    0.0000  14.304     681  0.0177
  0.3453  2.2399  0.1855  0.7535  0.1183  5.7427  0.0720  4.7073  0.0339  3.4214
  0.0230  1.8926  0.0122  1.0226  0.0057  0.3277  0.0029  6.0363  0.0027  5.2620
  0.0035  4.0601  0.0045  2.7810  0.0051  1.5249  0.0049  0.2780  0.0042  5.3026
M55 V8
  0.7219610000    0.0000  14.383     720  0.0144
  0.2477  0.1033  0.1028  2.9060  0.0546  5.9606  0.0207  2.6637  0.0080  6.0462
  0.0030  3.2395  0.0033  1.4701  0.0042  4.2614  0.0039  0.6673  0.0029  3.4124
  0.0018  6.2539  0.0011  3.2255  0.0014  0.4103  0.0020  3.4664  0.0021  0.0578
M68 V14
  0.5568000000    0.0000  15.731     117  0.0171
  0.4213  0.2430  0.1546  2.8492  0.1170  5.5152  0.0706  2.0283  0.0445  4.7338
  0.0290  1.0075  0.0228  3.6179  0.0181  0.1049  0.0119  2.7306  0.0093  5.6632
  0.0061  2.0383  0.0057  4.7881  0.0031  0.9186  0.0035  4.1899  0.0019  0.7005
M68 V22
  0.5634400000    0.0000  15.624     112  0.0158
  0.4028  3.4272  0.1572  2.8381  0.1032  2.4201  0.0840  2.1356  0.0596  1.8230
  0.0465  1.5839  0.0330  1.4957  0.0227  1.2522  0.0179  1.1063  0.0113  0.7689
  0.0073  0.3112  0.0055  0.1886  0.0041  6.0119  0.0041  6.2046  0.0029  5.6539
M68 V23
  0.6589200000    0.0000  15.610     117  0.0089
  0.3368  5.6910  0.1600  1.1482  0.1196  3.2521  0.0793  5.3990  0.0511  1.3617
  0.0271  3.5324  0.0156  5.5418  0.0092  1.2783  0.0050  3.6992  0.0029  1.1376
  0.0033  3.2965  0.0039  6.0629  0.0046  1.5674  0.0030  3.5570  0.0044  5.7536
M68 V30
  0.7336400000    0.0000  15.616     117  0.0076
  0.1649  2.8543  0.0589  1.9729  0.0279  1.3549  0.0110  1.2557  0.0056  1.4860
  0.0041  1.3893  0.0028  0.8541  0.0018  0.1119  0.0011  5.7620  0.0005  5.6793
  0.0004  6.2644  0.0004  6.1034  0.0002  5.7265  0.0001  0.8957  0.0002  3.7227
M68 V35
  0.7025000000    0.0000  15.569     109  0.0194
  0.3300  0.2275  0.1664  2.9282  0.1159  5.8876  0.0715  2.6749  0.0432  5.7123
  0.0251  2.4433  0.0137  5.4519  0.0068  2.2152  0.0032  5.4721  0.0022  2.7667
  0.0025  6.1590  0.0032  2.9266  0.0036  5.9023  0.0036  2.6126  0.0033  5.6656
M92 V1
  0.7028180000    0.0000  15.106      75  0.0084
  0.3076  3.7970  0.1456  3.6778  0.0938  3.8710  0.0580  4.4223  0.0277  4.8338
  0.0153  4.9616  0.0113  5.3737  0.0057  0.1860  0.0028  1.1622  0.0039  1.2661
  0.0020  1.3601  0.0027  2.5413  0.0026  2.3408  0.0011  3.1467  0.0019  3.8975
M92 V3
  0.6374751000    0.0000  15.176      74  0.0039
  0.3833  0.0584  0.1723  2.4127  0.1305  5.0212  0.0972  1.4485  0.0630  4.2415
  0.0368  0.8750  0.0182  3.1755  0.0151  5.8152  0.0128  2.2389  0.0086  5.2295
  0.0041  1.8363  0.0009  5.1755  0.0013  0.2056  0.0007  2.3820  0.0013  1.5090
M92 V4
  0.6289128000    0.0000  15.096      75  0.0140
  0.3143  3.5233  0.1438  3.0821  0.1164  2.8115  0.0655  2.6281  0.0407  2.5312
  0.0252  2.4755  0.0147  2.4648  0.0079  2.5015  0.0036  2.7148  0.0018  3.3768
  0.0017  4.1023  0.0019  4.1506  0.0020  4.0355  0.0020  3.4032  0.0016  3.0158
M92 V5
  0.6196963000    0.0000  15.181      73  0.0157
  0.3610  2.1377  0.1393  0.2605  0.1153  4.9190  0.0697  3.3477  0.0463  1.8256
  0.0279  0.4439  0.0147  5.4208  0.0066  4.1207  0.0027  2.6200  0.0019  0.7759
  0.0022  5.6143  0.0022  4.4227  0.0019  3.2410  0.0014  1.9097  0.0011  0.2084
M92 V6
  0.5999990000    0.0000  15.129      50  0.0133
  0.3931  0.4596  0.1754  3.3005  0.1035  0.1428  0.0752  2.9293  0.0618  6.2477
  0.0380  3.2047  0.0217  6.2239  0.0157  3.2523  0.0078  6.1763  0.0016  1.8611
  0.0022  6.2496  0.0004  4.3932  0.0013  2.4238  0.0011  5.4645  0.0007  2.3730
M92 V8
  0.6732614000    0.0000  15.137      72  0.0074
  0.2521  6.1197  0.1126  1.8878  0.0793  4.2802  0.0380  0.3525  0.0163  2.7875
  0.0064  5.3442  0.0032  1.4771  0.0024  3.8045  0.0018  0.4153  0.0014  3.5425
  0.0009  5.7747  0.0011  0.9396  0.0010  3.5336  0.0002  0.1515  0.0004  6.2767
M107 V8
  0.5599210000    0.0000  15.653     151  0.0200
  0.3563  2.8736  0.1880  1.8788  0.1289  1.2505  0.0770  0.7413  0.0382  0.0570
  0.0198  5.4902  0.0120  4.5863  0.0077  3.7675  0.0043  3.0170  0.0016  2.1038
  0.0011  5.7505  0.0025  4.7877  0.0034  4.1324  0.0036  3.5106  0.0034  2.8774
M107 V10
  0.4155170000    0.0000  15.819     140  0.0249
  0.3502  0.2891  0.1782  2.5212  0.1548  5.4639  0.0794  2.1633  0.0513  4.8212
  0.0367  1.2855  0.0262  4.1169  0.0183  0.6967  0.0125  3.5559  0.0085  0.1032
  0.0059  2.8913  0.0043  5.6485  0.0034  2.1357  0.0028  4.9674  0.0023  1.6019
M107 V12
  0.4728750000    0.0000  15.747     125  0.0185
  0.3323  2.3273  0.1007  0.7574  0.0217  0.0162  0.0138  6.2006  0.0138  5.8068
  0.0136  4.5427  0.0112  3.3430  0.0066  2.4177  0.0030  2.1231  0.0029  1.9199
  0.0022  0.9008  0.0011  5.3410  0.0012  3.0993  0.0012  1.2653  0.0012  5.6612
M107 V14
  0.4816129000    0.0000  15.773     120  0.0111
  0.4357  4.3204  0.2333  4.6195  0.1515  5.3154  0.0980  5.8761  0.0622  0.3718
  0.0359  0.9661  0.0299  1.3956  0.0315  1.9409  0.0239  2.4315  0.0144  2.9547
  0.0086  3.3531  0.0046  4.5017  0.0058  5.1259  0.0048  5.9567  0.0025  5.9224
M107 V17
  0.5611700000    0.0000  15.652     116  0.0229
  0.3475  2.1446  0.1910  0.4744  0.1255  5.3621  0.0827  4.0852  0.0470  2.7650
  0.0311  1.2018  0.0207  6.1642  0.0115  4.8035  0.0000  0.0000  0.0000  0.0000
  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000
M107 V18
  0.5643780000    0.0000  15.775      52  0.0102
  0.2930  1.1441  0.1443  4.9210  0.0936  2.6730  0.0555  0.5852  0.0222  4.5570
  0.0080  1.9958  0.0035  0.7128  0.0053  5.7432  0.0067  3.7128  0.0068  1.4863
  0.0066  5.4729  0.0063  3.1760  0.0059  0.9169  0.0055  4.9821  0.0049  2.7877
M107 V20
  0.5781113000    0.0000  15.777     119  0.0151
  0.2799  0.2572  0.1449  3.0611  0.0866  6.2074  0.0516  3.1390  0.0198  0.0954
  0.0139  3.3119  0.0060  0.8955  0.0076  4.7568  0.0091  1.6638  0.0089  4.7377
  0.0076  1.5128  0.0060  4.5681  0.0048  1.3393  0.0040  4.4043  0.0036  1.2120
N1851 V1
  0.5205888000    0.0000  16.132     113  0.0144
  0.4473  2.6011  0.2208  1.2218  0.1557  0.2172  0.0997  5.4404  0.0765  4.4969
  0.0494  3.5758  0.0277  2.4583  0.0235  1.2194  0.0180  0.2391  0.0120  5.6400
  0.0075  4.8363  0.0049  3.6176  0.0038  1.9653  0.0016  0.5590  0.0024  3.3999
N1851 V6
  0.6066231000    0.0000  16.123     113  0.0188
  0.2970  0.2921  0.1557  3.1041  0.0959  6.2037  0.0521  3.1373  0.0227  0.0076
  0.0123  2.7021  0.0071  5.8168  0.0028  3.3931  0.0034  1.7060  0.0050  5.2343
  0.0053  2.2228  0.0047  5.3682  0.0038  2.0818  0.0032  4.9085  0.0032  1.4114
N1851 V7
  0.5851851000    0.0000  16.095     108  0.0104
  0.3627  0.6786  0.1890  3.7666  0.1206  0.9217  0.0844  4.3580  0.0463  1.6432
  0.0229  5.0215  0.0127  1.9594  0.0098  5.6668  0.0018  2.8663  0.0022  1.7879
  0.0046  0.5828  0.0023  3.8220  0.0040  0.4794  0.0032  3.7021  0.0050  1.1922
N1851 V12
  0.5759556000    0.0000  16.156     111  0.0125
  0.3216  0.7394  0.1611  3.9304  0.1064  1.1446  0.0699  4.6935  0.0374  2.0788
  0.0153  5.3634  0.0089  2.5378  0.0034  0.4650  0.0043  5.3674  0.0058  2.8798
  0.0054  0.1403  0.0043  3.5582  0.0034  0.6169  0.0031  4.0265  0.0032  1.3186
N1851 V16
  0.4886849000    0.0000  16.195     110  0.0293
  0.4360  3.2109  0.2048  2.4717  0.1358  1.8961  0.0709  1.3289  0.0444  0.9384
  0.0270  0.5386  0.0146  0.0527  0.0068  5.6035  0.0041  4.3722  0.0045  3.4478
  0.0045  2.9702  0.0038  2.7103  0.0030  2.6396  0.0025  2.7106  0.0023  2.7367
N5466 V3
  0.5780645000    0.0000  16.581      86  0.0228
  0.3840  6.1330  0.1756  1.8372  0.1420  4.3355  0.0953  0.4318  0.0608  3.0076
  0.0389  5.4860  0.0249  1.5743  0.0162  3.8628  0.0110  6.1103  0.0076  2.0885
  0.0051  4.4077  0.0030  0.5370  0.0012  3.1942  0.0007  1.0782  0.0017  4.1249
N5466 V8
  0.6291182000    0.0000  16.558      89  0.0141
  0.3349  6.0850  0.1542  1.8821  0.1112  4.3525  0.0731  0.5114  0.0443  3.1667
  0.0233  5.6933  0.0104  1.8706  0.0036  4.2266  0.0007  6.1415  0.0002  6.2224
  0.0008  0.8284  0.0019  3.0318  0.0029  5.4766  0.0035  1.7118  0.0036  4.2625
N5466 V9
  0.6850366000    0.0000  16.483      90  0.0188
  0.3382  0.5031  0.1697  3.4543  0.1123  0.4164  0.0739  3.7486  0.0372  0.7540
  0.0192  4.0101  0.0113  1.0198  0.0060  4.4955  0.0031  2.1638  0.0031  0.0554
  0.0039  3.7109  0.0041  0.8683  0.0039  4.2354  0.0034  1.2788  0.0028  4.5658
N5466 V10
  0.7092782000    0.0000  16.465      89  0.0130
  0.3085  5.8359  0.1560  1.6702  0.1004  4.0392  0.0595  0.3188  0.0248  2.6542
  0.0095  4.9384  0.0038  1.2687  0.0030  4.5632  0.0041  1.1263  0.0047  3.7226
  0.0045  6.2809  0.0039  2.5595  0.0032  5.1215  0.0025  1.3696  0.0020  3.8251
N5466 V14
  0.7858557000    0.0000  16.408      90  0.0133
  0.2401  4.4413  0.1114  5.3259  0.0643  0.2223  0.0223  1.3131  0.0084  2.9592
  0.0074  4.7344  0.0075  5.9992  0.0065  0.8338  0.0052  1.9491  0.0040  3.1146
  0.0033  4.3199  0.0029  5.4854  0.0026  0.2628  0.0022  1.2071  0.0016  2.0176
N6362 V254
  0.5328880000    0.0000  15.219      97  0.0222
  0.3832  3.5028  0.1935  3.0749  0.1064  2.9631  0.0730  2.9360  0.0388  2.8766
  0.0232  2.6195  0.0175  2.3588  0.0143  2.2516  0.0112  2.2681  0.0081  2.3634
  0.0055  2.5085  0.0036  2.6576  0.0022  2.6897  0.0014  2.3179  0.0016  1.6618
N6362 V329
  0.4558900000    0.0000  15.379      97  0.0238
  0.4411  1.6641  0.2115  5.5706  0.1543  3.5100  0.1007  1.4782  0.0728  5.7622
  0.0521  3.7992  0.0361  1.8349  0.0243  6.1270  0.0160  4.0880  0.0106  1.9883
  0.0075  6.1328  0.0057  4.0258  0.0046  2.0186  0.0037  0.1365  0.0030  4.6607
N6362 V377
  0.5256700000    0.0000  15.331      87  0.0128
  0.3597  0.0735  0.1849  2.5438  0.1231  5.3487  0.0824  1.8576  0.0471  4.7338
  0.0258  1.2786  0.0133  4.0456  0.0059  0.4549  0.0014  2.8112  0.0019  3.2374
  0.0038  5.7938  0.0050  2.2156  0.0057  4.9602  0.0059  1.4431  0.0057  4.2230
N6362 V424
  0.5945060000    0.0000  15.345      98  0.0126
  0.2203  3.2038  0.0963  2.7012  0.0539  2.5090  0.0214  2.6725  0.0077  3.3662
  0.0076  3.5073  0.0077  3.8771  0.0051  3.3042  0.0000  0.0000  0.0000  0.0000
  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000
N6981 V159
  0.6738650000    0.0000  16.658      69  0.0188
  0.3801  1.7717  0.1988  6.2195  0.1332  4.3662  0.0772  2.8497  0.0462  1.2347
  0.0278  5.8179  0.0165  4.0416  0.0097  2.1918  0.0056  0.2861  0.0030  4.6320
  0.0010  2.5213  0.0009  4.7014  0.0023  2.6783  0.0033  0.8842  0.0039  5.4105
N6981 V263
  0.5581700000    0.0000  16.910      69  0.0175
  0.3180  0.3061  0.1406  2.9436  0.1210  5.8813  0.0687  2.7562  0.0382  5.8815
  0.0206  2.6854  0.0103  5.7870  0.0045  2.7514  0.0022  0.2293  0.0023  3.9772
  0.0027  0.8891  0.0027  3.8954  0.0025  0.5556  0.0022  3.4846  0.0020  0.1499
N6981 V307
  0.5311640000    0.0000  16.975      69  0.0175
  0.3592  2.1785  0.1683  0.2840  0.1230  5.0787  0.0798  3.5817  0.0508  2.2841
  0.0310  0.8657  0.0174  5.6035  0.0090  3.8891  0.0050  1.9078  0.0039  6.1439
  0.0037  4.3821  0.0033  2.8379  0.0029  1.4002  0.0026  6.2690  0.0023  4.8011
IC4499 V34
  0.4935580000    0.0000  17.727      73  0.0204
  0.4561  5.1529  0.1920  0.0056  0.1538  1.2884  0.1054  2.8600  0.0739  4.3423
  0.0527  5.8242  0.0377  1.0265  0.0268  2.5080  0.0189  3.9771  0.0131  5.4248
  0.0090  0.5592  0.0062  1.9428  0.0044  3.3048  0.0033  4.6835  0.0026  6.1295
IC4499 V2
  0.4936360000    0.0000  17.742     113  0.0317
  0.4547  4.4339  0.1958  4.9000  0.1538  5.4906  0.1030  0.0116  0.0700  0.6508
  0.0487  1.5558  0.0370  2.2826  0.0316  3.2437  0.0196  4.2664  0.0129  4.8438
  0.0149  5.7456  0.0138  0.7308  0.0100  1.8371  0.0088  2.6296  0.0090  3.6379
IC4499 V27
  0.5067600000    0.0000  17.763     105  0.0209
  0.4284  3.5673  0.1754  3.1116  0.1346  2.9884  0.1051  2.8787  0.0611  2.6855
  0.0458  2.7680  0.0256  2.7850  0.0146  2.7736  0.0094  2.7401  0.0064  2.6908
  0.0041  2.6200  0.0022  2.4725  0.0009  1.9145  0.0009  0.7111  0.0013  0.4428
IC4499 V88
  0.5725610600    0.0000  17.589      67  0.0163
  0.4468  2.3479  0.2160  0.7459  0.1539  5.7292  0.1078  4.3554  0.0838  3.0685
  0.0513  2.0674  0.0318  0.6793  0.0206  5.5704  0.0125  4.3078  0.0071  3.1391
  0.0044  1.9925  0.0036  0.7895  0.0036  5.8508  0.0037  4.6681  0.0031  3.5323
IC4499 V45
  0.6058940000    0.0000  17.716      62  0.0124
  0.2573  1.3746  0.1143  5.1279  0.0727  2.9101  0.0493  0.7834  0.0177  4.9107
  0.0102  1.8698  0.0099  6.2311  0.0045  4.1578  0.0048  3.0593  0.0000  0.0000
  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000
IC4499 V64
  0.6361450000    0.0000  17.657      61  0.0108
  0.2654  4.1521  0.1337  4.4876  0.0769  5.1235  0.0441  5.8305  0.0235  0.3679
  0.0116  1.3488  0.0062  2.6210  0.0052  3.8882  0.0049  4.7764  0.0044  5.4115
  0.0039  5.9163  0.0034  0.1084  0.0028  0.6246  0.0020  1.1993  0.0011  1.8239
oCen V74
  0.7729000000    0.0000  14.460     210  0.0093
  0.2503  4.6284  0.1154  5.7562  0.0661  0.8530  0.0265  2.2493  0.0131  3.7943
  0.0065  5.5896  0.0057  1.2957  0.0064  2.8236  0.0065  4.1092  0.0058  5.3306
  0.0047  0.2777  0.0035  1.5652  0.0026  2.9437  0.0021  4.3899  0.0017  5.8012
oCen V77
  0.5644000000    0.0000  14.754     222  0.0267
  0.3601  5.1312  0.1850  0.1344  0.1168  1.6551  0.0670  3.3091  0.0345  4.9652
  0.0165  0.4166  0.0076  2.4277  0.0055  4.7697  0.0062  0.4737  0.0064  2.1776
  0.0059  3.8035  0.0049  5.4522  0.0036  0.9535  0.0027  3.0520  0.0032  5.2471
oCen V82
  0.6204000000    0.0000  14.603     223  0.0183
  0.4091  1.1616  0.2057  4.6827  0.1393  2.2744  0.1012  6.1605  0.0608  3.8129
  0.0322  1.2619  0.0235  4.8856  0.0194  2.5421  0.0098  0.2896  0.0027  4.3865
  0.0035  1.8461  0.0026  5.5759  0.0016  4.9832  0.0014  1.8632  0.0019  0.1505
oCen V85
  0.5032000000    0.0000  14.702     227  0.0114
  0.4649  0.1723  0.2052  2.5589  0.1537  5.1998  0.0977  1.7281  0.0681  4.4832
  0.0501  1.0414  0.0306  3.8983  0.0182  0.3117  0.0113  2.8855  0.0093  5.5769
  0.0093  2.1434  0.0052  5.0141  0.0041  2.1374  0.0027  5.1023  0.0018  0.7706
oCen V87
  0.7130402880    0.0000  14.630     211  0.0194
  0.3303  5.7206  0.1748  1.4760  0.1107  3.7000  0.0571  6.0938  0.0312  2.0910
  0.0182  4.3646  0.0112  0.4223  0.0073  2.9020  0.0055  5.5406  0.0051  1.9106
  0.0053  4.4358  0.0053  0.5597  0.0050  2.8888  0.0043  5.1585  0.0035  1.0851
oCen V88
  0.5675461340    0.0000  14.764     145  0.0102
  0.3445  6.2597  0.1772  2.3678  0.1164  5.0917  0.0774  1.6325  0.0451  4.4352
  0.0243  0.8295  0.0145  3.3287  0.0106  0.0806  0.0051  3.0128  0.0028  0.3301
  0.0026  2.9980  0.0023  0.4420  0.0026  2.4427  0.0048  6.2249  0.0025  2.3014
oCen V89
  0.6304709110    0.0000  14.609     367  0.0354
  0.3980  4.3673  0.1963  4.7972  0.1321  5.5658  0.0914  0.0668  0.0615  0.9659
  0.0414  1.7406  0.0280  2.4377  0.0188  3.1201  0.0120  3.8396  0.0069  4.6506
  0.0031  5.7217  0.0018  1.3070  0.0026  2.7511  0.0029  3.6598  0.0026  4.3725
oCen V90
  0.7339503410    0.0000  14.524     596  0.0231
  0.2872  4.9310  0.1441  6.2156  0.0866  1.4266  0.0420  3.0733  0.0212  4.5651
  0.0118  0.0187  0.0063  1.7964  0.0013  3.9440  0.0042  0.0134  0.0055  1.7098
  0.0038  3.1095  0.0051  4.5331  0.0053  5.5077  0.0031  0.6046  0.0022  3.2593
oCen V99
  0.6273000000    0.0000  14.566     226  0.0133
  0.3776  2.5155  0.1889  1.1024  0.1306  0.0531  0.0888  5.3017  0.0582  4.4063
  0.0302  3.2137  0.0204  1.9417  0.0154  1.0160  0.0104  0.2428  0.0025  5.4374
  0.0028  5.3211  0.0031  3.8169  0.0034  3.8552  0.0023  2.8383  0.0029  1.9963
oCen V102
  0.6349000000    0.0000  14.570     145  0.0107
  0.3766  5.6910  0.1925  1.1974  0.1322  3.3286  0.0892  5.5257  0.0517  1.4770
  0.0296  3.5089  0.0220  5.5426  0.0148  1.5147  0.0100  3.8812  0.0057  6.1194
  0.0052  2.1429  0.0025  5.2130  0.0016  0.8631  0.0030  3.8761  0.0033  6.1544
oCen V107
  0.6340999280    0.0000  14.576     285  0.0224
  0.3820  3.3761  0.2008  2.8836  0.1334  2.6576  0.0931  2.5036  0.0616  2.5400
  0.0279  2.0539  0.0266  1.7476  0.0116  1.7937  0.0062  1.2583  0.0003  5.8819
  0.0041  2.2876  0.0024  3.2267  0.0042  3.0447  0.0035  2.6570  0.0029  1.6729
oCen V109
  0.6116000000    0.0000  14.471     116  0.0244
  0.3483  3.5448  0.1765  3.1329  0.1167  3.0621  0.0820  2.9458  0.0547  3.0047
  0.0303  2.8386  0.0206  2.5241  0.0151  2.4372  0.0086  2.5018  0.0029  2.4176
  0.0013  1.1322  0.0013  1.1104  0.0009  2.9524  0.0023  3.9023  0.0030  4.3112
oCen V113
  0.5885000000    0.0000  14.546     100  0.0101
  0.3970  4.3241  0.1701  4.7068  0.0841  5.2991  0.0462  5.9662  0.0235  0.4976
  0.0150  0.7226  0.0080  1.6775  0.0047  1.3391  0.0028  1.3175  0.0000  0.0000
  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000
oCen V117
  0.6197985730    0.0000  14.525     260  0.0115
  0.3980  4.8366  0.2003  5.7640  0.1367  0.7215  0.0949  1.9467  0.0615  3.3142
  0.0306  4.4401  0.0237  5.4352  0.0176  0.5614  0.0099  2.0618  0.0041  3.1227
  0.0016  5.2526  0.0006  6.2021  0.0021  3.2893  0.0026  4.2647  0.0026  5.6889
oCen V120
  0.7846000000    0.0000  14.520      99  0.0067
  0.2368  5.0000  0.1053  0.2024  0.0608  1.9023  0.0259  3.6476  0.0105  5.2098
  0.0061  0.8200  0.0024  3.4950  0.0021  5.4542  0.0030  1.0007  0.0017  3.3523
  0.0009  1.4280  0.0014  2.3856  0.0004  3.1812  0.0023  1.3805  0.0005  1.8545
oCen V124
  0.8106724050    0.0000  14.447     205  0.0185
  0.2788  4.4208  0.1328  5.4253  0.0734  0.2626  0.0320  1.4731  0.0126  2.9413
  0.0073  4.8896  0.0075  0.1763  0.0071  1.3405  0.0060  2.3545  0.0046  3.3194
  0.0032  4.3162  0.0019  5.4558  0.0008  0.8208  0.0009  3.1288  0.0013  4.6784
oCen V128
  0.5733000000    0.0000  14.665      98  0.0131
  0.4376  4.1961  0.2037  4.3647  0.1479  4.9410  0.0972  5.4616  0.0717  6.1630
  0.0436  0.4443  0.0288  0.8801  0.0173  1.1345  0.0126  1.8749  0.0079  2.9310
  0.0057  2.7356  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000
oCen V133
  0.7439000000    0.0000  14.486      99  0.0136
  0.3569  2.1843  0.1850  0.8073  0.1132  5.8519  0.0526  4.7133  0.0320  3.4214
  0.0201  2.3204  0.0038  0.0209  0.0034  6.2404  0.0049  1.1265  0.0021  4.2999
  0.0039  4.1453  0.0063  2.8225  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000
oCen V137
  0.7661860000    0.0000  14.352     267  0.0436
  0.4306  6.2502  0.1956  2.5442  0.1410  5.1844  0.0606  1.8190  0.0380  4.2065
  0.0190  0.4226  0.0090  2.7042  0.0055  5.1833  0.0026  2.2757  0.0035  0.2063
  0.0054  3.4650  0.0055  0.2618  0.0042  3.3481  0.0023  0.2995  0.0011  4.2159
oCen V146
  0.5108754000    0.0000  14.873     366  0.0316
  0.3663  1.0225  0.1797  4.3312  0.1260  1.7853  0.0835  5.4432  0.0503  2.9451
  0.0304  0.3523  0.0186  3.9574  0.0115  1.2461  0.0067  4.8431  0.0031  2.2490
  0.0005  0.7274  0.0022  6.0457  0.0037  3.5631  0.0046  1.0321  0.0050  4.7831
oCen V147
  0.5741436800    0.0000  14.568     150  0.0081
  0.4269  2.5651  0.1975  1.1336  0.1467  0.0508  0.0969  5.2447  0.0694  4.2228
  0.0429  3.2628  0.0230  2.1662  0.0185  0.9139  0.0151  6.0475  0.0100  5.2292
  0.0062  4.4306  0.0036  2.9004  0.0034  2.0571  0.0037  1.7328  0.0020  0.9096
oCen V150
  0.4743000000    0.0000  14.654      82  0.0179
  0.3880  4.3512  0.1897  4.6359  0.1374  5.1772  0.0918  5.7880  0.0628  0.2364
  0.0433  0.9340  0.0297  1.5929  0.0201  2.2245  0.0136  2.8445  0.0091  3.4788
  0.0062  4.1709  0.0043  4.9795  0.0034  5.9359  0.0031  0.6663  0.0032  1.6048
oCen V153
  0.6913940040    0.0000  14.588     656  0.0203
  0.3289  5.7844  0.1756  1.5514  0.1114  3.8098  0.0637  6.2628  0.0303  2.2711
  0.0204  4.4088  0.0102  0.9086  0.0053  3.5870  0.0032  5.9718  0.0034  2.9668
  0.0046  5.0569  0.0040  1.0904  0.0032  4.0211  0.0032  6.0781  0.0034  2.4120
oCen V154
  0.5141063000    0.0000  14.873     362  0.0282
  0.4131  3.6349  0.2013  3.2601  0.1423  3.2926  0.0938  3.1989  0.0591  3.3269
  0.0390  3.3734  0.0269  3.3237  0.0196  3.2157  0.0149  3.0960  0.0116  2.9993
  0.0088  2.9407  0.0065  2.9262  0.0043  2.9687  0.0025  3.1234  0.0012  3.6710
oCen V158
  0.6478449570    0.0000  14.585     360  0.0163
  0.3585  0.2564  0.1856  2.9507  0.1237  5.9423  0.0839  2.7388  0.0476  5.9198
  0.0242  2.3283  0.0215  5.3195  0.0110  2.3771  0.0063  5.6260  0.0020  2.0130
  0.0018  5.6907  0.0043  2.8758  0.0019  6.2389  0.0032  3.3368  0.0029  0.3057
oCen V159
  0.6918908870    0.0000  14.557     359  0.0174
  0.3301  2.1921  0.1750  0.6117  0.1098  5.5862  0.0649  4.5116  0.0317  3.1914
  0.0207  1.8714  0.0132  0.7002  0.0060  0.2048  0.0046  4.8602  0.0021  4.7608
  0.0060  3.9005  0.0054  2.4240  0.0043  1.2411  0.0040  5.9877  0.0031  4.5110
oCen V163
  0.6155563650    0.0000  14.615     306  0.0200
  0.3913  4.8055  0.1943  5.7116  0.1246  0.6504  0.0802  1.9083  0.0523  3.2740
  0.0240  4.4418  0.0153  5.3145  0.0148  0.1661  0.0093  1.8832  0.0027  2.4369
  0.0018  4.3558  0.0028  5.4924  0.0005  3.5902  0.0018  3.9657  0.0020  5.1290
oCen V165
  0.6046346580    0.0000  14.727     252  0.0204
  0.3441  0.4936  0.1661  3.2767  0.1215  0.1567  0.0768  3.3534  0.0479  0.3505
  0.0237  3.4427  0.0130  6.2735  0.0098  3.2069  0.0058  0.8419  0.0019  4.6025
  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000
oCen V166
  0.5928748190    0.0000  14.649     260  0.0138
  0.4165  3.7877  0.1999  3.5877  0.1421  3.8156  0.0960  3.9202  0.0690  4.2460
  0.0381  4.4374  0.0205  4.3758  0.0177  4.3904  0.0134  4.7807  0.0078  5.0814
  0.0039  5.2898  0.0015  5.0974  0.0005  6.2714  0.0014  0.5123  0.0012  2.9176
oCen V170
  0.7790502180    0.0000  14.523     261  0.0173
  0.2297  0.2243  0.1007  3.2802  0.0580  0.2394  0.0234  3.8306  0.0122  0.8381
  0.0056  4.6357  0.0067  2.2942  0.0081  5.5292  0.0077  2.2830  0.0063  5.2635
  0.0047  1.9826  0.0032  5.1236  0.0024  2.2571  0.0025  5.7648  0.0028  2.7686
oCen V176
  0.7427499070    0.0000  14.494     230  0.0129
  0.2783  4.4293  0.1365  5.2360  0.0790  6.2725  0.0297  1.1407  0.0143  2.2827
  0.0077  4.0270  0.0036  5.8091  0.0052  0.7867  0.0065  1.7554  0.0069  2.6344
  0.0061  3.5759  0.0053  4.7609  0.0026  6.0426  0.0029  0.4776  0.0035  1.4976
oCen V179
  0.5890223320    0.0000  14.609     231  0.0314
  0.4208  1.8045  0.2075  5.9379  0.1458  4.0844  0.0948  2.1720  0.0694  0.4255
  0.0451  4.8450  0.0262  3.0197  0.0166  0.7438  0.0097  5.2179  0.0048  3.3547
  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000
oCen V180
  0.6869580330    0.0000  14.551     231  0.0165
  0.3306  3.4662  0.1718  3.2085  0.1125  3.1960  0.0675  3.3392  0.0365  3.2131
  0.0209  3.1473  0.0110  3.6829  0.0045  3.5313  0.0021  3.7299  0.0052  4.4786
  0.0030  4.2257  0.0024  5.2542  0.0022  5.9377  0.0053  5.8286  0.0041  5.1208
oCen V182
  0.6023365240    0.0000  14.603     232  0.0127
  0.4005  5.3358  0.1961  0.4367  0.1371  2.1639  0.0971  3.8693  0.0617  5.6943
  0.0346  1.1471  0.0196  2.7352  0.0163  4.3533  0.0102  0.0442  0.0054  2.2149
  0.0021  4.5388  0.0045  0.0622  0.0042  1.1258  0.0012  3.5907  0.0026  5.5202
oCen V188
  0.6690505380    0.0000  14.542     157  0.0148
  0.3304  6.0577  0.1763  2.0721  0.1204  4.5714  0.0788  0.8261  0.0375  3.5852
  0.0215  6.0256  0.0211  2.1790  0.0123  4.6706  0.0062  1.1434  0.0029  4.5276
  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000  0.0000
oCen V199
  0.5213260950    0.0000  14.747     280  0.0176
  0.4577  6.0112  0.2049  1.6944  0.1571  3.9012  0.1016  6.2192  0.0715  2.2415
  0.0502  4.6557  0.0301  0.7666  0.0186  3.1699  0.0156  5.2097  0.0117  1.1824
  0.0101  3.5682  0.0058  6.1838  0.0043  2.9364  0.0023  4.5909  0.0022  1.5094
oCen V200
  0.6217000000    0.0000  14.596     280  0.0154
  0.3969  4.6473  0.1977  5.3721  0.1341  0.1629  0.0924  1.2111  0.0615  2.4025
  0.0313  3.4181  0.0240  4.2681  0.0191  5.4102  0.0125  0.4299  0.0076  1.5531
  0.0058  2.5724  0.0029  3.5910  0.0019  4.8137  0.0006  4.1081  0.0034  3.4731
oCen V204
  0.6082799800    0.0000  14.657     274  0.0128
  0.3889  6.0918  0.1891  1.9934  0.1315  4.5642  0.0923  0.8022  0.0584  3.4967
  0.0284  5.9670  0.0216  1.9440  0.0158  4.6877  0.0101  1.2540  0.0052  3.5147
  0.0030  6.0391  0.0019  3.1019  0.0007  5.8021  0.0010  5.3027  0.0025  0.3915
oCen V206
  0.7944016290    0.0000  14.481     135  0.0128
  0.2235  3.5884  0.0958  3.7196  0.0554  4.0467  0.0243  4.4572  0.0092  5.0487
  0.0055  6.1390  0.0060  0.4965  0.0065  0.7864  0.0069  1.0278  0.0070  1.3163
  0.0066  1.6511  0.0056  2.0004  0.0043  2.3162  0.0030  2.5153  0.0022  2.5099
oCen V211
  0.5944634170    0.0000  14.671     218  0.0255
  0.3912  4.0669  0.1940  4.1162  0.1298  4.5866  0.0920  4.9802  0.0627  5.5772
  0.0309  6.0953  0.0198  6.0155  0.0183  0.4300  0.0163  1.1107  0.0034  1.3767
  0.0051  2.5037  0.0019  3.5864  0.0033  3.3457  0.0030  4.4517  0.0037  5.2945
Rup106 V1
  0.6101900000    0.0000  17.785     231  0.0203
  0.2325  2.3660  0.0991  0.8219  0.0721  5.9925  0.0340  4.8002  0.0213  4.0440
  0.0057  3.4758  0.0061  3.4847  0.0062  2.3469  0.0054  1.0068  0.0050  5.9628
  0.0048  4.7495  0.0045  3.6487  0.0039  2.6384  0.0033  1.6956  0.0027  0.7716
Rup106 V10
  0.6022200000    0.0000  17.741     232  0.0188
  0.2654  5.7588  0.1127  1.2654  0.0873  3.4364  0.0506  5.6494  0.0229  1.8065
  0.0072  4.6083  0.0044  0.8817  0.0052  3.6060  0.0060  5.8663  0.0045  1.8328
  0.0048  4.4271  0.0025  0.2865  0.0035  2.8530  0.0042  4.5940  0.0036  0.4651
Rup106 V13
  0.6531500000    0.0000  17.754     232  0.0132
  0.1663  1.0206  0.0560  4.4940  0.0209  1.7114  0.0012  0.0403  0.0033  5.9015
  0.0034  2.5682  0.0032  0.1172  0.0024  3.8176  0.0020  0.9463  0.0018  4.5377
  0.0009  2.0787  0.0001  2.1023  0.0006  0.2210  0.0002  4.3624  0.0005  4.6812
Rup106 V15
  0.6033000000    0.0000  17.804     232  0.0109
  0.2721  5.6092  0.1083  1.0253  0.0708  2.9365  0.0349  4.7855  0.0176  0.5544
  0.0068  2.4878  0.0020  4.2210  0.0025  0.0707  0.0019  1.3388  0.0003  3.0559
  0.0016  6.0393  0.0005  0.9911  0.0017  0.3054  0.0021  0.3741  0.0023  4.7225
Rup106 V16
  0.6285100000    0.0000  17.790     232  0.0123
  0.1969  1.7591  0.0814  5.9307  0.0477  4.2757  0.0223  2.7302  0.0098  1.7613
  0.0061  0.9121  0.0051  5.4351  0.0063  3.5654  0.0035  2.0070  0.0054  0.2947
  0.0041  5.3097  0.0018  4.1585  0.0012  1.2594  0.0004  0.8935  0.0008  5.4782
Rup106 V18
  0.6354700000    0.0000  17.797     232  0.0128
  0.1719  5.0084  0.0655  6.2115  0.0359  1.6020  0.0126  3.3666  0.0056  5.2849
  0.0053  1.6824  0.0040  3.0904  0.0041  4.8264  0.0037  0.2560  0.0023  1.9175
  0.0008  3.6355  0.0001  5.6461  0.0003  5.8419  0.0009  1.2948  0.0013  2.8976
""".strip()
